@@ -92,7 +92,7 @@ during periods of time where the statistics are disabled on a connection, are
 simply ignored in the statistics.
 
 For the Iter methods of WBEMConnection (e.g.
-:meth:`~pywbem.WbemConnection.IterEnumerateInstances`), the WBEM operations
+:meth:`~pywbem.WBEMConnection.IterEnumerateInstances`), the WBEM operations
 performed on behalf of them are subject of the statistics, but the Iter methods
 themselves do not show up in the statistics.
 
@@ -143,18 +143,21 @@ response times::
 """  # noqa: E501
 # pylint: enable=line-too-long
 
-from __future__ import absolute_import
 
 import time
 import copy
-import six
 
 from ._utils import _format
 
 __all__ = ['Statistics', 'OperationStatistic']
 
+# pylint: disable=consider-using-min-builtin
+# pylint: disable=consider-using-max-builtin
+#  replaces if statements with something like:
+#  self._reply_len_min = min(_reply_len_min, reply_len)
 
-class OperationStatistic(object):
+
+class OperationStatistic:
     # pylint: disable=too-many-instance-attributes
     """
     *New in pywbem 0.11 as experimental and finalized in 0.12.*
@@ -176,7 +179,7 @@ class OperationStatistic(object):
             The statistics container that holds this operation statistic
             object.
 
-          name (string):
+          name (str):
             Name of the operation.
         """
         self._container = container
@@ -207,7 +210,7 @@ class OperationStatistic(object):
     @property
     def stat_start_time(self):
         """
-        :class:`py:float`: Point in time when the first statistic was taken
+        float: Point in time when the first statistic was taken
         since this object was either created or reset, in seconds since the
         epoch (for details, see :func:`py:time.time`).
         """
@@ -216,7 +219,7 @@ class OperationStatistic(object):
     @property
     def name(self):
         """
-        :term:`string`: Name of the operation for which this statistics
+        str: Name of the operation for which this statistics
         object maintains data.
         """
         return self._name
@@ -232,14 +235,14 @@ class OperationStatistic(object):
     @property
     def count(self):
         """
-        :term:`integer`: The number of measured operations.
+        int: The number of measured operations.
         """
         return self._count
 
     @property
     def exception_count(self):
         """
-        :term:`integer`: The number of measured operations that resulted in an
+        int: The number of measured operations that resulted in an
         exception returned to the pywbem user (for example because a failure
         was indicated in the operation response of the WBEM server, or because
         pywbem itself detected a failure before sending the request or after
@@ -250,7 +253,7 @@ class OperationStatistic(object):
     @property
     def avg_time(self):
         """
-        :class:`py:float`: The average elapsed client time for execution of the
+        float: The average elapsed client time for execution of the
         measured operations, in seconds.
         """
         try:
@@ -261,7 +264,7 @@ class OperationStatistic(object):
     @property
     def min_time(self):
         """
-        :class:`py:float`: The minimum elapsed client time for execution of the
+        float: The minimum elapsed client time for execution of the
         measured operations, in seconds.
         """
         return self._time_min
@@ -269,7 +272,7 @@ class OperationStatistic(object):
     @property
     def max_time(self):
         """
-        :class:`py:float`: The maximum elapsed client time for execution of the
+        float: The maximum elapsed client time for execution of the
         measured operations, in seconds.
         """
         return self._time_max
@@ -277,7 +280,7 @@ class OperationStatistic(object):
     @property
     def avg_server_time(self):
         """
-        :class:`py:float`: The average elapsed server time for execution of the
+        float: The average elapsed server time for execution of the
         measured operations, in seconds.
 
         This time is 0 if the WBEM server did not return the WBEM server
@@ -291,7 +294,7 @@ class OperationStatistic(object):
     @property
     def min_server_time(self):
         """
-        :class:`py:float`: The minimum elapsed server time for execution of the
+        float: The minimum elapsed server time for execution of the
         measured operations, in seconds.
 
         This time is 0 if the WBEM server did not return the WBEM server
@@ -302,7 +305,7 @@ class OperationStatistic(object):
     @property
     def max_server_time(self):
         """
-        :class:`py:float`: The maximum elapsed server time for execution of the
+        float: The maximum elapsed server time for execution of the
         measured operations, in seconds.
 
         This time is 0 if the WBEM server did not return the WBEM server
@@ -313,7 +316,7 @@ class OperationStatistic(object):
     @property
     def avg_request_len(self):
         """
-        :class:`py:float`: The average size of the HTTP body in the CIM-XML
+        float: The average size of the HTTP body in the CIM-XML
         requests of the measured operations, in Bytes.
         """
         try:
@@ -324,7 +327,7 @@ class OperationStatistic(object):
     @property
     def min_request_len(self):
         """
-        :class:`py:float`: The minimum size of the HTTP body in the CIM-XML
+        float: The minimum size of the HTTP body in the CIM-XML
         requests of the measured operations, in Bytes.
         """
         return self._request_len_min
@@ -332,7 +335,7 @@ class OperationStatistic(object):
     @property
     def max_request_len(self):
         """
-        :class:`py:float`: The maximum size of the HTTP body in the CIM-XML
+        float: The maximum size of the HTTP body in the CIM-XML
         requests of the measured operations, in Bytes.
         """
         return self._request_len_max
@@ -340,7 +343,7 @@ class OperationStatistic(object):
     @property
     def avg_reply_len(self):
         """
-        :class:`py:float`: The average size of the HTTP body in the CIM-XML
+        float: The average size of the HTTP body in the CIM-XML
         responses of the measured operations, in Bytes.
         """
         try:
@@ -351,7 +354,7 @@ class OperationStatistic(object):
     @property
     def min_reply_len(self):
         """
-        :class:`py:float`: The minimum size of the HTTP body in the CIM-XML
+        float: The minimum size of the HTTP body in the CIM-XML
         responses of the measured operations, in Bytes.
         """
         return self._reply_len_min
@@ -359,7 +362,7 @@ class OperationStatistic(object):
     @property
     def max_reply_len(self):
         """
-        :class:`py:float`: The maximum size of the HTTP body in the CIM-XML
+        float: The maximum size of the HTTP body in the CIM-XML
         responses of the measured operations, in Bytes.
         """
         return self._reply_len_max
@@ -415,17 +418,17 @@ class OperationStatistic(object):
 
         Parameters:
 
-          request_len (:term:`integer`):
+          request_len (int):
             Size of the HTTP body of the CIM-XML request message, in Bytes.
 
-          reply_len (:term:`integer`):
+          reply_len (int):
             Size of the HTTP body of the CIM-XML response message, in Bytes.
 
-          exception (:class:`py:bool`):
+          exception (bool):
             Boolean that specifies whether an exception was raised while
             processing the operation.
 
-          server_time (:class:`py:bool`):
+          server_time (bool):
             Time in seconds that the server optionally returns to the
             client in the HTTP response defining the time from when the
             server received the request to when it started sending the
@@ -552,24 +555,21 @@ class OperationStatistic(object):
         This is a low-level method that is called by
         :meth:`pywbem.Statistics.formatted`.
         """
-        ret = ('{0:5d} {1:5d} {2:7.3f} {3:7.3f} {4:7.3f} '.
-               format(self.count, self.exception_count,
-                      self.avg_time, self.min_time, self.max_time))
+        ret = (f'{self.count:5d} {self.exception_count:5d} '
+               f'{self.avg_time:7.3f} {self.min_time:7.3f} '
+               f'{self.max_time:7.3f} ')
         if include_server_time:
-            ret += ('{0:7.3f} {1:7.3f} {2:7.3f} '.
-                    format(self.avg_server_time, self.min_server_time,
-                           self.max_server_time))
+            ret += (f'{self.avg_server_time:7.3f} {self.min_server_time:7.3f} '
+                    f'{self.max_server_time:7.3f} ')
         if include_lengths:
-            ret += ('{0:6.0f} {1:6.0f} {2:6.0f} '
-                    '{3:8.0f} {4:8.0f} {5:8.0f} '.
-                    format(self.avg_request_len, self.min_request_len,
-                           self.max_request_len, self.avg_reply_len,
-                           self.min_reply_len, self.max_reply_len))
-        ret += '{0}\n'.format(self.name)
+            ret += (f'{self.avg_request_len:6.0f} {self.min_request_len:6.0f} '
+                    f'{self.max_request_len:6.0f} {self.avg_reply_len:8.0f} '
+                    f'{self.min_reply_len:8.0f} {self.max_reply_len:8.0f} ')
+        ret += f'{self.name}\n'
         return ret
 
 
-class Statistics(object):
+class Statistics:
     """
     *New in pywbem 0.11 as experimental and finalized in 0.12.*
 
@@ -599,7 +599,7 @@ class Statistics(object):
         """
         Parameters:
 
-          enable (:class:`py:bool`):
+          enable (bool):
             Initial enablement status for this statistics container.
         """
         # We convert any non-boolean values to True/False:
@@ -658,7 +658,7 @@ class Statistics(object):
     @property
     def enabled(self):
         """
-        Indicates whether the statistics container is enabled.
+        bool: Indicates whether the statistics container is enabled.
         """
         return self._enabled
 
@@ -686,7 +686,7 @@ class Statistics(object):
 
         Parameters:
 
-          name (string):
+          name (str):
             Name of the operation.
 
         Returns:
@@ -706,7 +706,7 @@ class Statistics(object):
 
         Parameters:
 
-          name (string):
+          name (str):
             Name of the operation.
 
         Returns:
@@ -731,9 +731,10 @@ class Statistics(object):
 
         Returns:
 
-          : A list of tuples (name, stats) with:
+          list of tuple: A list of tuple (name, stats) with the following tuple
+          items:
 
-          - name (:term:`string`): Name of the operation
+          - name (str): Name of the operation
           - stats (:class:`~pywbem.OperationStatistic`): Time statistics for
             the operation
         """
@@ -807,10 +808,11 @@ class Statistics(object):
         Reset all statistics and clear any statistic names.
         All statistics must be inactive before a reset will execute
 
-        Returns: True if reset, False if not
+        Returns:
+            bool: True if reset, False if not.
         """
         # Test for any stats being currently timed.
-        for stat in six.itervalues(self._op_stats):
+        for stat in self._op_stats.values():
             if stat._start_time is not None:  # pylint: disable=protected-access
                 return False
 
