@@ -19,10 +19,9 @@ In addition, the following subdirectories exist that do not contain tests:
   some testcases in end2end tests.
 """
 
-from __future__ import absolute_import, print_function
 import os
 from .utils import import_installed
 pywbem = import_installed('pywbem')  # pylint: disable=invalid-name
 
-print("Testing pywbem version {0} from {1}".
-      format(pywbem.__version__, os.path.dirname(pywbem.__file__)))
+print(f"Testing pywbem version {pywbem.__version__} from "
+      f"{os.path.dirname(pywbem.__file__)}")
