@@ -6,20 +6,14 @@ End2end tests of indications from a wbem server. This tests:
 because OpenPegasus defines a provider in its test environment specifically to
 send indications based on a method invocation and we have a container
 implementation of OpenPegasus.
-
 """
 
-from __future__ import absolute_import, print_function
-
 import socket
 import time
-import sys
 import os
 import datetime
 import logging
 
-from pytest import skip
-
 from .utils.pytest_extensions import skip_if_unsupported_capability
 
 # Note: The wbem_connection fixture uses the es_server fixture, and
@@ -68,15 +62,9 @@ def test_indications(wbem_connection):  # noqa: F811
     # define repeat_loop and indication_count variables to rerun the test with
     # each of these pairs. (repeat_loop, indication_count)
     # FUTURE: Expand this to more indications when we resolve issue #3022,
-    # the container not returning all of the indications.  This appears to
-    # be much more consistent with python 3.7 and 3.7 PACKAGE_LEVEL=minimum
+    # the container not returning all of the indications.
 
-    # Skipping tests for python 2.7 and 3.7 if issues losing indications
-    if sys.version_info[0:2] in ((2, 7), (3, 7)):
-        test_run_loops = None  # avoid pylint issue
-        skip("Skipping test_indications for python 2.7, 3.7")
-    else:
-        test_run_loops = ((1, 1), (1, 2), (1, 10), (1, 100), (1, 1000))
+    test_run_loops = ((1, 1), (1, 2), (1, 10), (1, 100), (1, 1000))
 
     for params in test_run_loops:
         repeat_loop = params[0]
@@ -87,7 +75,7 @@ def test_indications(wbem_connection):  # noqa: F811
                           verbose=verbose)
 
 
-class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
+class RunIndicationTest:  # pylint: disable=too-many-instance-attributes
     """
     Runs a test that:
     1. Creates a server
@@ -102,7 +90,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
     # a class that generates one indication for each call of a method
     indication_test_class = 'Test_IndicationProviderClass'
     test_class_namespace = 'test/TestProvider'
-    test_query = 'SELECT * from %s' % indication_test_class
+    test_query = f'SELECT * from {indication_test_class}'
 
     # If set, outputs all of the requests (apis and html) and responses to
     # pywbem log file. This is not same log as the listener output.
@@ -126,14 +114,14 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                 OpenPegasus server because the indication generator is defined
                 as part of that server
 
-            indication_destination_host (:term:`string`):
+            indication_destination_host (str):
                 host name/ip address containing the listener.  This is
                 the address to where indications are sent by the WBEM server.
                 If the WBEM server is on a different system or in a container
                 this must be an address usable by that system/container.
                 Localhost is not a valid host name in that case.
 
-            listener_host (:term:`string` or None):
+            listener_host (:class:`py:str` or None):
                 host name/ip address that will be used by the listener as
                 its bind address. If this parameter contains
                 a string that will be passed to WBEMListener as the host
@@ -144,24 +132,24 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                 If None the listener will be forwarded indications addressed
                 to any IP address in the containing computer system.
 
-            http_listener_port (:term:`number`):
+            http_listener_port (int):
                 listener port for indications sent with http.
 
-            request_indications (:term:`number`):
+            request_indications (int):
                 Number of indications requested from server for. The default
                 is 1 indication.
 
-            repeat_loop (:term:`number`):
+            repeat_loop (int):
                 The number of times the request indications method is to
                 be sent to the server.  It is sent to request that the
                 server generate the number of indications defined by the
                 request_indications parameter and when that number of
                 indications has been received
 
-            output_log (:class:`py:bool`):
+            output_log (bool):
                 Flag to indicate whether the server should generate a log.
 
-            verbose (:class:`py:bool`):
+            verbose (bool):
                 Flag that when set generates diagnostic displays as the
                 test proceedes.
         """
@@ -176,8 +164,8 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
         self.verbose = verbose
         self.logfile = 'pegasusindicationtest.log'
         if self.verbose:
-            print("Listener indication_destination_host IP address {}".
-                  format(self.indication_destination_host))
+            print("Listener indication_destination_host IP address "
+                  f"{self.indication_destination_host}")
 
         # Define WBEM server CIMClassName for test indication class
         self.indication_test_class_name = \
@@ -211,7 +199,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
 
         if os.path.exists(self.logfile):
             if verbose:
-                print("Removing old indication logfile {}".format(self.logfile))
+                print(f"Removing old indication logfile {self.logfile}")
             os.remove(self.logfile)
 
         logging.basicConfig(filename='pegasusindicationtest.log',
@@ -238,8 +226,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                 print("Removed existing subscriptions")
 
         except Error as er:  # pylint: disable=invalid-name
-            print('Error {} communicating with WBEMServer {}'.format(er,
-                                                                     self.conn))
+            print(f'Error {er} communicating with WBEMServer {self.conn}')
             assert False
 
         self.create_listener()
@@ -250,7 +237,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
         success = self.repeat_test_loop(self.repeat_loop)
 
         completion_status = "Success" if success else "Failed"
-        print("Indication test completed: {}".format(completion_status))
+        print(f"Indication test completed: {completion_status}")
 
         # Remove server_id which removes owned subscriptions for this server_id
         sub_mgr.remove_server(self.server_id)
@@ -278,7 +265,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
         self.listener.add_callback(self.consume_indication)
 
         if self.verbose:
-            print("Starting listener\n {}".format(self.listener))
+            print(f"Starting listener\n {self.listener}")
         self.listener.start()
 
     def create_subscription(self, server_id, sub_mgr):
@@ -289,9 +276,9 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
         """
 
         # Create the destination instance
-        indication_dest_url = \
-            "http://{0}:{1}".format(self.indication_destination_host,
-                                    self.http_listener_port)
+        indication_dest_url = (
+            f"http://{self.indication_destination_host}:"
+            f"{self.http_listener_port}")
 
         destination = sub_mgr.add_destination(
             server_id, indication_dest_url,
@@ -308,9 +295,10 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
             server_id, filter_.path, destination_paths=destination.path)
 
         if self.verbose:
-            print("Subscription instances\n {0}\n{1}\n{2}".
-                  format(filter_.tomof(), destination.tomof(),
-                         subscriptions[0].tomof()))
+            print("Subscription instances:\n"
+                  f"{filter_.tomof()}\n"
+                  f"{destination.tomof()}\n"
+                  f"{subscriptions[0].tomof()}")
 
     def repeat_test_loop(self, repeat_loop):
         """
@@ -364,11 +352,11 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
             self.received_indication_count = 1
         else:
             exp_seq_num = self.last_seq_num + 1
-            assert seq_num == exp_seq_num, \
-                'Missed {0} indications at seq_num={1}. rcvd seq num={2}, ' \
-                'expected={3}'. \
-                format((seq_num - 1) - self.last_seq_num,
-                       self.last_seq_num, seq_num, exp_seq_num)
+            missed_num = (seq_num - 1) - self.last_seq_num
+            assert seq_num == exp_seq_num, (
+                f'Missed {missed_num} indications at seq_num='
+                f'{self.last_seq_num}. rcvd seq num={seq_num}, '
+                f'expected={exp_seq_num}')
             self.received_indication_count += 1
 
         self.last_seq_num = seq_num
@@ -397,16 +385,17 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
             insts = self.conn.EnumerateInstances(
                 'PG_ListenerDestinationQueue', namespace='root/PG_Internal')
             for inst in insts:
-                print('ListenerDestinationName={}:\n   QueueFullDropped={} , '
-                      'RetryAttemptsExceeded={}, InQueue={}'
-                      .format(inst['ListenerDestinationName'],
-                              inst['QueueFullDroppedIndications'],
-                              inst['RetryAttemptsExceededIndications'],
-                              inst['CurrentIndications']))
+                print("ListenerDestinationName="
+                      f"{inst['ListenerDestinationName']}:\n"
+                      "   QueueFullDropped="
+                      f"{inst['QueueFullDroppedIndications']}, "
+                      "RetryAttemptsExceeded="
+                      f"{inst['RetryAttemptsExceededIndications']}, "
+                      f"InQueue={inst['CurrentIndications']}")
 
                 if self.verbose:
-                    print("Full instnace of OpenPegasus dest queue:\n{}".
-                          format(inst.tomof()))
+                    print("Full instnace of OpenPegasus dest queue:\n"
+                          f"{inst.tomof()}")
         return success
 
     def get_elapsed_time(self):
@@ -462,10 +451,8 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                 if self.received_indication_count >= self.requested_indications:
                     elapsed_time, ind_per_sec = self.get_elapsed_time()
 
-                    print('Rcvd {} indications, time={} sec, {:.2f} per sec'
-                          .format(self.received_indication_count,
-                                  elapsed_time,
-                                  ind_per_sec))
+                    print(f"Rcvd {self.received_indication_count} indications, "
+                          f"time={elapsed_time} sec, {ind_per_sec:.2f} per sec")
                     return_flag = True
                     break
 
@@ -474,7 +461,7 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                     last_indication_count = self.received_indication_count
                     stall_ctr = 0
 
-                    print("Rcvd {} indications.".format(last_indication_count))
+                    print(f"Rcvd {last_indication_count} indications.")
                     continue
 
                 # Nothing received in last loop and requested number not rcvd.
@@ -489,17 +476,15 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
                 if stall_ctr > 5:
                     elapsed_time, ind_per_sec = self.get_elapsed_time()
 
-                    print('Nothing received for {} sec: received={} '
-                          'time={} sec: {:.2f} per sec. stall ctr={}'.
-                          format(stalled_time.total_seconds(),
-                                 self.received_indication_count,
-                                 elapsed_time,
-                                 ind_per_sec,
-                                 stall_ctr))
+                    print("Nothing received for "
+                          f"{stalled_time.total_seconds()} sec: "
+                          f"received={self.received_indication_count} "
+                          f"time={elapsed_time} sec: {ind_per_sec:.2f} "
+                          f"per sec. stall ctr={stall_ctr}")
                     break
 
-                print("waiting {:.2f} sec. with no indications ct {}".
-                      format(stalled_time.total_seconds(), stall_ctr))
+                print(f"waiting {stalled_time.total_seconds():.2f} sec. with "
+                      f"no indications ct {stall_ctr}")
 
         # Because this can be a long loop, catch CTRL-C
         except KeyboardInterrupt:
@@ -510,9 +495,9 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
         if return_flag:
             time.sleep(1)
             if self.received_indication_count != self.requested_indications:
-                print('ERROR. Extra indications received {}, requested {}'.
-                      format(self.received_indication_count,
-                             self.requested_indications))
+                print("ERROR. Extra indications received "
+                      f"{self.received_indication_count}, "
+                      f"requested {self.requested_indications}")
             if return_flag:
                 assert self.received_indication_count == \
                     self.requested_indications
@@ -536,9 +521,9 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
 
             if self.verbose:
                 print("Send InvokeMethod to WBEM Server:")
-                print("  class_name {0} method {1} for {2} indications".
-                      format(class_name, send_indication_method,
-                             indication_count))
+                print(f"  class_name {class_name} method "
+                      f"{send_indication_method} for {indication_count} "
+                      "indications")
 
             result = self.conn.InvokeMethod(
                 send_indication_method, class_name,
@@ -546,13 +531,12 @@ class RunIndicationTest(object):  # pylint: disable=too-many-instance-attributes
 
             if result[0] != 0:
                 print('Error: SendTestIndicationCount Method error. '
-                      'Nonzero return from InvokeMethod={}'
-                      .format(result[0]))
+                      f'Nonzero return from InvokeMethod={result[0]}')
                 return False
             return True
 
         except Error as er:  # pylint: disable=invalid-name
-            print('Error: Indication Method exception {}'.format(er))
+            print(f'Error: Indication Method exception {er}')
             return False
 
     @staticmethod
