@@ -2,10 +2,6 @@
 Assertion functions for pywbem end2end tests.
 """
 
-from __future__ import absolute_import
-
-import six
-
 from pywbem import CIMInstance, CIMInstanceName
 from pywbem._utils import _format
 
@@ -24,12 +20,12 @@ def assert_number_of_instances_equal(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        exp_number (integer): Expected number of instances or instance paths.
+        exp_number (int): Expected number of instances or instance paths.
 
-        inst_list (list of CIMInstanceName or CIMInstance): List of instances
-          or instance paths to be tested.
+        inst_list (:class:`py:list` of CIMInstanceName or CIMInstance): List of
+          instances or instance paths to be tested.
 
-        inst_list_msg (string): Short definition what inst_list is.
+        inst_list_msg (str): Short definition what inst_list is.
     """
     if len(inst_list) != exp_number:
         raise AssertionError(
@@ -49,12 +45,12 @@ def assert_number_of_instances_minimum(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        exp_number (integer): Expected number of instances or instance paths.
+        exp_number (int): Expected number of instances or instance paths.
 
-        inst_list (list of CIMInstanceName or CIMInstance): List of instances
-          or instance paths to be tested.
+        inst_list (:class:`py:list` of CIMInstanceName or CIMInstance): List of
+          instances or instance paths to be tested.
 
-        inst_list_msg (string): Short definition what inst_list is.
+        inst_list_msg (str): Short definition what inst_list is.
     """
     if len(inst_list) < exp_number:
         raise AssertionError(
@@ -82,7 +78,7 @@ def assert_instance_of(conn, obj_list, classname):
         obj_list (CIMInstanceName or CIMInstance or tuple/list thereof):
           The CIM instances and CIM instance paths to be evaluated.
 
-        classname (string): The CIM class name.
+        classname (str): The CIM class name.
     """
 
     # TODO 2018-12 AM: Improve performance by avoiding EI on each path
@@ -186,7 +182,7 @@ def assert_mandatory_properties(conn, instance, property_list):
 
     instance_prop_names = instance.properties.keys()
     for prop_name in property_list:
-        assert isinstance(prop_name, six.string_types)
+        assert isinstance(prop_name, str)
 
         if prop_name not in instance_prop_names:
             raise AssertionError(
@@ -218,7 +214,7 @@ def assert_property_one_of(conn, instance, prop_name, value_list):
         instance (CIMInstance): The CIM instance that has the property to
           be verified.
 
-        prop_name (string): Name of the CIM property to be verified.
+        prop_name (str): Name of the CIM property to be verified.
 
         value_list (iterable of values): The set of allowable values for
           the property.
@@ -226,7 +222,7 @@ def assert_property_one_of(conn, instance, prop_name, value_list):
 
     # Check parameters
     assert isinstance(instance, CIMInstance)
-    assert isinstance(prop_name, six.string_types)
+    assert isinstance(prop_name, str)
     prop = instance.properties[prop_name]
     assert not prop.is_array
 
@@ -252,14 +248,14 @@ def assert_property_contains(conn, instance, prop_name, value):
         instance (CIMInstance): The CIM instance that has the property to
           be verified.
 
-        prop_name (string): Name of the CIM property to be verified.
+        prop_name (str): Name of the CIM property to be verified.
 
         value (value): The value.
     """
 
     # Check parameters
     assert isinstance(instance, CIMInstance)
-    assert isinstance(prop_name, six.string_types)
+    assert isinstance(prop_name, str)
     prop = instance.properties[prop_name]
     assert prop.is_array
 
@@ -292,17 +288,17 @@ def assert_path_equal(conn, path1, path1_msg, path2, path2_msg):
 
         path1 (CIMInstanceName): First instance path to be compared.
 
-        path1_msg (string): Short definition what path1 is.
+        path1_msg (str): Short definition what path1 is.
 
         path2 (CIMInstanceName): Second instance path to be compared.
 
-        path2_msg (string): Short definition what path2 is.
+        path2_msg (str): Short definition what path2 is.
     """
 
     # Check parameters
     # Note: path1 and path2 are checked in path_equal()
-    assert isinstance(path1_msg, six.string_types)
-    assert isinstance(path2_msg, six.string_types)
+    assert isinstance(path1_msg, str)
+    assert isinstance(path2_msg, str)
 
     if not path_equal(path1, path2):
         raise AssertionError(
@@ -326,18 +322,18 @@ def assert_path_in(conn, path, path_msg, path_list, path_list_msg):
         path (CIMInstanceName): Instance path to be tested for being contained
           in list.
 
-        path_msg (string): Short definition what path is.
+        path_msg (str): Short definition what path is.
 
         path_list (iterable of CIMInstanceName): List of instance paths tested
           for containing path.
 
-        path_list_msg (string): Short definition what path_list is.
+        path_list_msg (str): Short definition what path_list is.
     """
 
     # Check parameters
     # Note: path and path_list are checked in path_in()
-    assert isinstance(path_msg, six.string_types)
-    assert isinstance(path_list_msg, six.string_types)
+    assert isinstance(path_msg, str)
+    assert isinstance(path_list_msg, str)
 
     if not path_in(path, path_list):
         raise AssertionError(
@@ -363,17 +359,17 @@ def assert_association_a1(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a1_assoc_insts = conn.References(
@@ -431,17 +427,17 @@ def assert_association_a2(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a2_assoc_insts = conn.References(
@@ -506,17 +502,17 @@ def assert_association_a3(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a3_assoc_paths = conn.ReferenceNames(
@@ -583,17 +579,17 @@ def assert_association_a4(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a4_assoc_paths = conn.ReferenceNames(
@@ -665,17 +661,17 @@ def assert_association_a5(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a5_assoc_insts = conn.EnumerateInstances(
@@ -738,17 +734,17 @@ def assert_association_a6(
 
         conn (WBEMConnection with 'es_server' attribute)
 
-        profile_id (string): Profile org and name as 'org:name'
+        profile_id (str): Profile org and name as 'org:name'
 
         source_path (CIMInstanceName): Instance path of the source instance.
 
-        source_role (string): Filter: Role on source end of association.
+        source_role (str): Filter: Role on source end of association.
 
-        source_class (string): Filter: Class name of source end of association.
+        source_class (str): Filter: Class name of source end of association.
 
-        far_role (string): Filter: Role on far end of association.
+        far_role (str): Filter: Role on far end of association.
 
-        far_class (string): Filter: Class name of far end of association.
+        far_class (str): Filter: Class name of far end of association.
     """
 
     a6_assoc_paths = conn.EnumerateInstanceNames(
@@ -841,7 +837,7 @@ def _assert_association_consistency(
     for path in far_paths:
         assert_path_in(
             conn, path, far_paths_msg,
-            far_insts, "path of {0}".format(far_insts_msg))
+            far_insts, f"path of {far_insts_msg}")
 
     assert_instance_of(conn, assoc_insts, assoc_class)
     for inst in assoc_insts:
@@ -850,21 +846,21 @@ def _assert_association_consistency(
         assert_path_equal(
             conn,
             inst.path.keybindings[source_role],
-            "source end {0!r} of {1}".format(source_role, assoc_insts_msg),
+            f"source end {source_role!r} of {assoc_insts_msg}",
             source_path,
             "source instance")
         assert far_role in inst.path.keybindings
         assert_path_in(
             conn,
             inst.path.keybindings[far_role],
-            "far end {0!r} of {1}".format(far_role, assoc_insts_msg),
+            f"far end {far_role!r} of {assoc_insts_msg}",
             far_paths,
             far_paths_msg)
     for path in assoc_paths:
         assert_path_in(
             conn,
             path, assoc_paths_msg,
-            assoc_insts, "path of {0}".format(assoc_insts_msg))
+            assoc_insts, f"path of {assoc_insts_msg}")
 
     # Check consistency across the association approaches
     # Py test does not seem to have a reliable order of executing the
@@ -943,10 +939,10 @@ def assert_profile_tree(conn, profile_inst, profile_ancestry,
             * key: std_uri of profile that is tested.
             * value: std_uri of its referencing profile (or spec, for the top).
 
-        reference_direction (string): Reference direction to use for the test
+        reference_direction (str): Reference direction to use for the test
           ('dmtf' or 'snia').
 
-        tls_org (string), tls_name (string): Org and name of top level spec
+        tls_org (str), tls_name (str): Org and name of top level spec
           of the profile tree (used only for failure messages).
     """
 
@@ -954,10 +950,10 @@ def assert_profile_tree(conn, profile_inst, profile_ancestry,
 
     # from pprint import pprint
     # print("Debug: assert_profile_tree called")
-    # print("       profile:  {0}".format(profile_uri))
+    # print(f"       profile:  {profile_uri}")
     # print("       ancestry: ")
     # for k in profile_ancestry.keys():
-    #     print("                 {0}".format(k))
+    #     print(f"                 {k}")
 
     if reference_direction == 'dmtf':
         result_role_down = 'Antecedent'
@@ -984,14 +980,12 @@ def assert_profile_tree(conn, profile_inst, profile_ancestry,
 
             if sub_profile_uri in profile_ancestry:
                 raise AssertionError(
-                    "Server {0} at {1}: Profile tree under top level "
-                    "specification {2} {3!r} has a circular reference: "
-                    "Profile at {4} references profile at {5} which is "
-                    "already in its own reference ancestry {6}".
-                    format(conn.es_server.nickname, conn.url,
-                           tls_org, tls_name,
-                           profile_uri, sub_profile_uri,
-                           profile_ancestry.keys()))
+                    f"Server {conn.es_server.nickname} at {conn.url}: "
+                    "Profile tree under top level specification "
+                    f"{tls_org} {tls_name!r} has a circular reference: "
+                    f"Profile at {profile_uri} references profile at "
+                    f"{sub_profile_uri} which is already in its own reference "
+                    f"ancestry {profile_ancestry.keys()}")
 
             profile_ancestry[sub_profile_uri] = profile_uri
 
