@@ -2,20 +2,11 @@
 Pytest fixtures for pywbem end2end tests.
 """
 
-from __future__ import absolute_import
-
 import os
-import io
 import warnings
 from contextlib import contextmanager
 import json
 import subprocess
-try:
-    from subprocess import DEVNULL
-except ImportError:
-    # Python 2.7
-    from subprocess import PIPE as DEVNULL
-import six
 import pytest
 import yaml
 
@@ -40,7 +31,7 @@ PROFILES_YAML_FILE = os.path.join('tests', 'profiles', 'profiles.yml')
 # Profile definition list.
 # The list items are profile definition items, as described in the profile
 # definition file.
-with io.open(PROFILES_YAML_FILE, 'r', encoding='utf-8') as _fp:
+with open(PROFILES_YAML_FILE, encoding='utf-8') as _fp:
     PROFILE_DEFINITION_LIST = yaml.safe_load(_fp)
 del _fp  # pylint: disable=undefined-loop-variable
 
@@ -67,7 +58,7 @@ def server_from_docker(image_name, image_port, host_port, container_name,
 
     Parameters:
 
-      image_name (string):
+      image_name (str):
         Docker image name on DockerHub, e.g. org/name:1.2.3. If None, the
         context manager does nothing and returns None.
 
@@ -75,7 +66,7 @@ def server_from_docker(image_name, image_port, host_port, container_name,
 
       host_port (int): Port number on host (local) system
 
-      container_name (string): Docker container name to use locally
+      container_name (str): Docker container name to use locally
 
       verbose (bool): Print messages.
 
@@ -88,20 +79,19 @@ def server_from_docker(image_name, image_port, host_port, container_name,
         try:
             inspect_out = subprocess.check_output(
                 ['docker', 'container', 'inspect', container_name],
-                stderr=DEVNULL)
-        except EnvironmentError as exc:
+                stderr=subprocess.DEVNULL)
+        except OSError as exc:
             raise RuntimeError(
-                "Docker does not seem to be installed: {}".format(exc))
+                f"Docker does not seem to be installed: {exc}")
         except subprocess.CalledProcessError as exc:
             if exc.returncode > 1:
                 raise RuntimeError(
-                    "Command 'docker container inspect ...' failed: {}".
-                    format(exc))
+                    f"Command 'docker container inspect ...' failed: {exc}")
             container_exists = False
             container_running = False
         else:
             container_exists = True
-            if isinstance(inspect_out, six.binary_type):
+            if isinstance(inspect_out, bytes):
                 inspect_out = inspect_out.decode('utf-8')
             _inspect_dict = json.loads(inspect_out)
             _status = _inspect_dict[0]['State']['Status']
@@ -110,31 +100,29 @@ def server_from_docker(image_name, image_port, host_port, container_name,
         if not container_exists:
             docker_pull_with_cache(image_name, verbose=verbose)
             if verbose:
-                print("Creating Docker container {} with "
-                      "image {}".format(container_name, image_name))
+                print(f"Creating Docker container {container_name} with "
+                      f"image {image_name}")
             subprocess.check_call(
                 ['docker', 'create',
                  '--name', container_name,
-                 '--publish', '{}:{}'.format(host_port, image_port),
+                 '--publish', f'{host_port}:{image_port}',
                  image_name],
-                stdout=DEVNULL)
+                stdout=subprocess.DEVNULL)
         else:
             if verbose:
-                print("Using existing Docker container {}".
-                      format(container_name))
+                print(f"Using existing Docker container {container_name}")
 
         if not container_running:
             if verbose:
-                print("Starting Docker container {}".format(container_name))
+                print(f"Starting Docker container {container_name}")
             subprocess.check_call(
                 ['docker', 'start', container_name],
-                stdout=DEVNULL)
+                stdout=subprocess.DEVNULL)
         else:
             if verbose:
-                print("Docker container {} was already running".
-                      format(container_name))
+                print(f"Docker container {container_name} was already running")
 
-        yield 'https://localhost:{}'.format(host_port)
+        yield f'https://localhost:{host_port}'
 
         # Leave the container running on exit.
     else:
@@ -160,7 +148,7 @@ def docker_pull_with_cache(image_name, verbose=False):
 
     Parameters:
 
-      image_name (string): Docker image name on DockerHub, e.g. org/name:1.2.3
+      image_name (str): Docker image name on DockerHub, e.g. org/name:1.2.3
 
       verbose (bool): Print messages.
     """
@@ -169,8 +157,7 @@ def docker_pull_with_cache(image_name, verbose=False):
 
     if not os.path.exists(cache_dir):
         if verbose:
-            print("Creating local Docker image cache directory: {}".
-                  format(cache_dir))
+            print(f"Creating local Docker image cache directory: {cache_dir}")
         os.makedirs(cache_dir, 0o755)
 
     image_tar_fn = image_name.replace('/', '_').replace(':', '_') + '.tar'
@@ -179,26 +166,26 @@ def docker_pull_with_cache(image_name, verbose=False):
     if not os.path.exists(image_tar_path):
 
         if verbose:
-            print("Pulling image from Docker Hub: {}".format(image_name))
+            print(f"Pulling image from Docker Hub: {image_name}")
         subprocess.check_call(
             ['docker', 'pull', image_name],
-            stdout=DEVNULL)
+            stdout=subprocess.DEVNULL)
 
         if verbose:
-            print("Saving image {} in local Docker image cache: {}".
-                  format(image_name, image_tar_path))
+            print(f"Saving image {image_name} in local Docker image cache: "
+                  f"{image_tar_path}")
         subprocess.check_call(
             ['docker', 'save', '-o', image_tar_path, image_name],
-            stdout=DEVNULL)
+            stdout=subprocess.DEVNULL)
 
     else:
 
         if verbose:
-            print("Loading image {} from local Docker image cache: {}".
-                  format(image_name, image_tar_path))
+            print(f"Loading image {image_name} from local Docker image cache: "
+                  f"{image_tar_path}")
         subprocess.check_call(
             ['docker', 'load', '-i', image_tar_path],
-            stdout=DEVNULL)
+            stdout=subprocess.DEVNULL)
 
 
 def skip_if_unsupported_capability(conn, cap_name):
@@ -207,8 +194,9 @@ def skip_if_unsupported_capability(conn, cap_name):
     by the server at the connection.
     """
     if not supports_capability(conn, cap_name):
-        pytest.skip("Server {} does not support capability: {}".
-                    format(conn.es_server.nickname, cap_name))
+        pytest.skip(
+            f"Server {conn.es_server.nickname} does not support capability: "
+            f"{cap_name}")
 
 
 def supports_capability(conn, cap_name):
@@ -251,8 +239,8 @@ def wbem_connection(request, es_server):  # noqa: F811
     # Note: We add an attribute to the es_server object to store this info.
     skip_msg = getattr(es_server, 'skip_msg', None)
     if skip_msg:
-        pytest.skip("Remembered skip reason from earlier attempt: {0}".
-                    format(skip_msg))
+        pytest.skip(
+            f"Remembered skip reason from earlier attempt: {skip_msg}")
 
     nickname = es_server.nickname
 
@@ -279,14 +267,14 @@ def wbem_connection(request, es_server):  # noqa: F811
         if port_mapping:
             image_port = int(port_mapping['image'])
             host_port = int(port_mapping['host'])
-        container_name = 'pywbem_end2endtest_{}'.format(nickname)
+        container_name = f'pywbem_end2endtest_{nickname}'
 
     with server_from_docker(
             image_name, image_port, host_port, container_name,
             verbose=verbose):
 
         if verbose:
-            print("Creating WBEM connection to: {}".format(url))
+            print(f"Creating WBEM connection to: {url}")
 
         conn = WBEMConnectionAsserted(
             url, (user, password), x509=x509,
@@ -306,15 +294,14 @@ def wbem_connection(request, es_server):  # noqa: F811
                 'Association',
                 asserted=False)
         except ConnectionError as exc:
-            msg = "Server {0} at {1}: Server cannot be reached: {2} - {3}". \
-                format(nickname, url, exc.__class__.__name__, exc)
+            msg = (f"Server {nickname} at {url}: Server cannot be reached: "
+                   f"{exc.__class__.__name__} - {exc}")
             es_server.skip_msg = msg
             warnings.warn(msg, ToleratedServerIssueWarning)
             pytest.skip(msg)
         except AuthError as exc:
-            msg = "Server {0} at {1}: Server cannot be authenticated with: " \
-                "{2} - {3}". \
-                format(nickname, url, exc.__class__.__name__, exc)
+            msg = (f"Server {nickname} at {url}: Server cannot be "
+                   f"authenticated with: {exc.__class__.__name__} - {exc}")
             es_server.skip_msg = msg
             warnings.warn(msg, ToleratedServerIssueWarning)
             pytest.skip(msg)
@@ -328,7 +315,7 @@ def wbem_connection(request, es_server):  # noqa: F811
         yield conn
 
         if verbose:
-            print("Closing WBEM connection to: {}".format(url))
+            print(f"Closing WBEM connection to: {url}")
         conn.close()
 
 
@@ -338,10 +325,10 @@ def fixtureid_default_namespace(fixture_value):
     `default_namespace()`.
 
     Parameters:
-      * fixture_value (string): The default namespace for the test.
+      * fixture_value (str): The default namespace for the test.
     """
     ns = fixture_value
-    return "default_namespace={0}".format(ns)
+    return f"default_namespace={ns}"
 
 
 @pytest.fixture(
@@ -365,15 +352,14 @@ def fixtureid_profile_definition(fixture_value):
     `profile_definition()`.
 
     Parameters:
-      * fixture_value (dict): The profile definition dictionary of the profile.
+      fixture_value (dict): The profile definition dictionary of the profile.
     """
     pd = fixture_value
     assert isinstance(pd, dict)
     assert 'registered_name' in pd
     assert 'registered_org' in pd
-    return "profile_definition={0}:{1}:{2}". \
-        format(pd['registered_org'], pd['registered_name'],
-               pd.get('registered_version', 'any'))
+    return (f"profile_definition={pd['registered_org']}:"
+            f"{pd['registered_name']}:{pd.get('registered_version', 'any')}")
 
 
 def _apply_profile_definition_defaults(pd):
@@ -392,7 +378,7 @@ def _apply_profile_definition_defaults(pd):
             raise ValueError(
                 "Profile definition error: The reference_direction item of a "
                 "profile definition can only be defaulted when the registered "
-                "organisation is DMTF or SNIA, but it is {0}".format(org))
+                f"organisation is DMTF or SNIA, but it is {org}")
     if 'scoping_class' not in pd:
         pd['scoping_class'] = None
     if 'scoping_path' not in pd:
@@ -505,7 +491,7 @@ def assert_association_func(request):
     return request.param
 
 
-class ProfileTest(object):
+class ProfileTest:
     """
     Base class for end2end tests on a specific profile.
     """
@@ -544,8 +530,9 @@ class ProfileTest(object):
             self.profile_org, self.profile_name, self.profile_version)
         assert self.profile_definition is not None
 
-        self.profile_id = "{0}:{1}:{2}".format(
-            self.profile_org, self.profile_name, self.profile_version or 'any')
+        self.profile_id = (
+            f"{self.profile_org}:{self.profile_name}:"
+            f"{self.profile_version or 'any'}")
         profile_insts_id = self.profile_id + ':profile_insts'
 
         try:
@@ -561,10 +548,10 @@ class ProfileTest(object):
                 conn.url, profile_insts_id, profile_insts)
 
         if not profile_insts:
-            pytest.skip("{0} {1} profile (version {2}) is not advertised "
-                        "on server {3!r}".
-                        format(self.profile_org, self.profile_name,
-                               self.profile_version or 'any', self.conn.url))
+            pytest.skip(
+                f"{self.profile_org} {self.profile_name} profile "
+                f"(version {self.profile_version or 'any'}) is not advertised "
+                f"on server {self.conn.url!r}")
 
         self.profile_inst = latest_profile_inst(profile_insts)
         # pylint: enable=attribute-defined-outside-init
