@@ -2,7 +2,6 @@
 Utility functions for pywbem end2end tests.
 """
 
-from __future__ import absolute_import, print_function
 
 from copy import deepcopy
 
@@ -84,7 +83,7 @@ def path_in(inst_path, inst_path_list):
     return False
 
 
-class ServerObjectCache(object):
+class ServerObjectCache:
     """
     A cache for named lists of CIM objects from a particular WBEM server.
 
@@ -109,21 +108,20 @@ class ServerObjectCache(object):
         list_dict = self._server_dict[server_url]
         if list_name in list_dict:
             raise KeyError(
-                "List {0!r} for server {1!r} is already in the cache".
-                format(list_name, server_url))
+                f"List {list_name!r} for server {server_url!r} is already "
+                "in the cache")
         list_dict[list_name] = deepcopy(obj_list)
 
     def del_list(self, server_url, list_name):
         """Delete list_name"""
         if server_url not in self._server_dict:
             raise KeyError(
-                "Server {0!r} is not in the cache".
-                format(server_url))
+                f"Server {server_url!r} is not in the cache")
         list_dict = self._server_dict[server_url]
         if list_name not in list_dict:
             raise KeyError(
-                "List {0!r} for server {1!r} is not in the cache".
-                format(list_name, server_url))
+                f"List {list_name!r} for server {server_url!r} is not in "
+                "the cache")
         del list_dict[list_name]
         if not list_dict:
             del self._server_dict[server_url]
@@ -132,13 +130,12 @@ class ServerObjectCache(object):
         """Get the list named list_name"""
         if server_url not in self._server_dict:
             raise KeyError(
-                "Server {0!r} is not in the cache".
-                format(server_url))
+                f"Server {server_url!r} is not in the cache")
         list_dict = self._server_dict[server_url]
         if list_name not in list_dict:
             raise KeyError(
-                "List {0!r} for server {1!r} is not in the cache".
-                format(list_name, server_url))
+                f"List {list_name!r} for server {server_url!r} is not in "
+                "the cache")
         return list_dict[list_name]
 
     def has_list(self, server_url, list_name):
@@ -170,7 +167,7 @@ def instance_of(conn, obj_list, classname):
         obj_list (CIMInstanceName or CIMInstance or tuple/list thereof):
           The CIM instances and CIM instance paths to be evaluated.
 
-        classname (string): The CIM class name.
+        classname (str): The CIM class name.
     """
 
     assert obj_list is not None
@@ -205,10 +202,9 @@ def instance_of(conn, obj_list, classname):
         except CIMError as exc:
             if exc.status_code == CIM_ERR_INVALID_CLASS:
                 raise AssertionError(
-                    "Server {0} at {1}: Class {2!r} does not exist in "
-                    "namespace {3!r}".
-                    format(conn.es_server.nickname, conn.url,
-                           classname, namespace))
+                    f"Server {conn.es_server.nickname} at {conn.url}: "
+                    f"Class {classname!r} does not exist in "
+                    f"namespace {namespace!r}")
             conn.raise_as_assertion_error(exc, 'EnumerateInstanceNames')
         except Error as exc:
             conn.raise_as_assertion_error(exc, 'EnumerateInstanceNames')
@@ -242,7 +238,7 @@ class WBEMConnectionAsserted(WBEMConnection):
         """
         es_server = kwargs['es_server']
         del kwargs['es_server']
-        super(WBEMConnectionAsserted, self).__init__(*args, **kwargs)
+        super().__init__(*args, **kwargs)
         self.es_server = es_server
 
     def _call_op(self, funcname, *args, **kwargs):
@@ -259,7 +255,7 @@ class WBEMConnectionAsserted(WBEMConnection):
             # The default must be non-asserted, in order to allow all the
             # operation invocations in WBEMServer to do their error handling.
             asserted = False
-        func = getattr(super(WBEMConnectionAsserted, self), funcname)
+        func = getattr(super(), funcname)
         # returns a bound method
         if asserted:
             try:
@@ -273,15 +269,14 @@ class WBEMConnectionAsserted(WBEMConnection):
         """
         Return an AssertionError about the specified exception.
         """
-        parm_list = ["{0!r}".format(a) for a in args]
-        parm_list.extend(["{0}={1!r}".format(k, v) for k, v in kwargs.items()])
+        parm_list = [f"{a!r}" for a in args]
+        parm_list.extend([f"{k}={v!r}" for k, v in kwargs.items()])
         parm_str = ", ".join(parm_list)
         return AssertionError(
-            "Server {0} at {1}: WBEMConnection.{2}() failed and raised "
-            "{3} - {4}. "
-            "Parameters: ({5})".
-            format(self.es_server.nickname, self.url, funcname,
-                   exc.__class__.__name__, exc, parm_str))
+            f"Server {self.es_server.nickname} at {self.url}: "
+            f"WBEMConnection.{funcname}() failed and raised "
+            f"{exc.__class__.__name__} - {exc}. "
+            f"Parameters: ({parm_str})")
 
     def EnumerateInstances(self, *args, **kwargs):
         # pylint: disable=arguments-differ
@@ -453,15 +448,13 @@ def server_func_asserted(server, funcname, *args, **kwargs):
     try:
         return func(*args, **kwargs)
     except Error as exc:
-        parm_list = ["{0!r}".format(a) for a in args]
-        parm_list.extend(["{0}={1!r}".format(k, v) for k, v in kwargs.items()])
+        parm_list = [f"{a!r}" for a in args]
+        parm_list.extend([f"{k}={v!r}" for k, v in kwargs.items()])
         parm_str = ", ".join(parm_list)
         raise AssertionError(
-            "Server {0} at {1}: Calling WBEMServer.{2}() failed and "
-            "raised {3} - {4}. "
-            "Parameters: ({5})".
-            format(server.conn.es_server.nickname, server.conn.url,
-                   funcname, exc.__class__.__name__, exc, parm_str))
+            f"Server {server.conn.es_server.nickname} at {server.conn.url}: "
+            f"Calling WBEMServer.{funcname}() failed and raised "
+            f"{exc.__class__.__name__} - {exc}. Parameters: ({parm_str})")
 
 
 def server_prop_asserted(server, propname):
