@@ -14,7 +14,6 @@ The default for this test takes several minutes to run because of size of
 the maximum timeout (20 seconds)
 """
 
-from __future__ import absolute_import
 
 # pylint: disable=missing-docstring,superfluous-parens,no-self-use
 import sys
@@ -23,8 +22,6 @@ import warnings
 import datetime
 from getpass import getpass
 
-import six
-
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from tests.utils import import_installed
 pywbem = import_installed('pywbem')
@@ -40,7 +37,7 @@ TESTCLASS = 'Test_CLITestProviderClass'
 TESTMETHOD = 'delayedMethodResponse'
 
 
-class ElapsedTimer(object):
+class ElapsedTimer:
     """
         Set up elapsed time timer. Calculates time between initiation
         and access.
@@ -94,13 +91,12 @@ class ClientTest(unittest.TestCase):
 
         # set this because python 3 http libs generate many ResourceWarnings
         # and unittest enables these warnings.
-        if not six.PY2:
-            # pylint: disable=undefined-variable
-            warnings.simplefilter("ignore", ResourceWarning)  # noqa: F821
+        # pylint: disable=undefined-variable
+        warnings.simplefilter("ignore", ResourceWarning)  # noqa: F821
 
     def connect(self, url, timeout=None):
 
-        self.log('setup connection {0} timeout {1}'.format(url, timeout))
+        self.log(f'setup connection {url} timeout {timeout}')
         conn = WBEMConnection(
             url,
             (args['username'], args['password']),
@@ -111,13 +107,13 @@ class ClientTest(unittest.TestCase):
 
         # enable saving xml for display
         conn.debug = args['debug']
-        self.log('Connected {0}'.format(url))
+        self.log(f'Connected {url}')
         return conn
 
     def log(self, data_):
         """Display log entry if verbose"""
         if self.debug:
-            print('{0}'.format(data_))
+            print(f'{data_}')
 
 
 class ServerTimeoutTest(ClientTest):
@@ -137,8 +133,7 @@ class ServerTimeoutTest(ClientTest):
         execution_time = None
 
         if self.debug:
-            print('execute url_type=%s timeout=%s delay=%s' % (url,
-                                                               timeout, delay))
+            print(f'execute url_type={url} timeout={timeout} delay={delay}')
 
         err_flag = ""
         opttimer = ElapsedTimer()
@@ -154,8 +149,8 @@ class ServerTimeoutTest(ClientTest):
             if delay > timeout:
                 err_flag = "Timeout Error: delay gt timeout"
                 if self.stop_on_err:
-                    self.fail('should not get good response for %delay > %s' %
-                              (delay, timeout))
+                    self.fail('should not get good response for '
+                              f'{delay} > {timeout}')
             if delay == timeout:
                 err_flag = "Good when timeout matches delay"
 
@@ -165,7 +160,7 @@ class ServerTimeoutTest(ClientTest):
             err_flag = "ConnectionError"
             execution_time = opttimer.elapsed_sec()
 
-            self.fail('%s exception %s' % ('Failed ConnectionError)', ce))
+            self.fail(f'Failed(ConnectionError) exception {ce}')
 
         # this exception tests against expected result. It terminates the
         # test only if the timeout is not expected
@@ -179,8 +174,7 @@ class ServerTimeoutTest(ClientTest):
             if delay < timeout:
                 err_flag = 'Error. delay < timeout'
                 if self.stop_on_err:
-                    self.fail('should not get timeout for %delay < %s' %
-                              (delay, timeout))
+                    self.fail(f'should not get timeout for {delay} < {timeout}')
             if delay == timeout:
                 err_flag = "Timeout when timeout matches delay"
 
@@ -190,19 +184,15 @@ class ServerTimeoutTest(ClientTest):
             execution_time = opttimer.elapsed_sec()
             request_result = 2
             if self.stop_on_err:
-                self.fail('%s exception %s' % ('Failed(Exception)', ec))
+                self.fail(f'Failed(Exception) exception {ec}')
 
         # generate table entry if verbose. This defines result for this
         # test
         if self.verbose:
             request_result_txt = ['Good Rtn', 'Timeout ', 'Failure']
 
-            print('%-12s %-7s %7d %5d %10.2f  %s' % (
-                url,
-                request_result_txt[request_result],
-                timeout, delay,
-                execution_time,
-                err_flag))
+            print(f'{url:-12s} {request_result_txt[request_result]:-7s} '
+                  f'{timeout:7d} {delay:5d} {execution_time:10.2f}  {err_flag}')
 
         return (request_result == 1)
 
@@ -214,9 +204,9 @@ class ServerTimeoutTest(ClientTest):
         for url_type in ['https', 'http']:
             if self.port:
                 if url_type == 'http':
-                    port = ":%s" % self.port
+                    port = f":{self.port}"
                 else:
-                    port = ":%s" % str(self.port + 1)
+                    port = f":{self.port + 1}"
             else:
                 port = ""
 
@@ -268,8 +258,8 @@ def parse_args(argv_):
         print('Complete test is in a single unittest function')
         print('')
         print('Usage:')
-        print('    %s [GEN_OPTS] URL [USERNAME%%PASSWORD [UT_OPTS '
-              '[UT_CLASS ...]]] ' % argv[0])
+        print(f'    {argv[0]} [GEN_OPTS] URL [USERNAME%%PASSWORD [UT_OPTS '
+              '[UT_CLASS ...]]] ')
         print('')
         print('Where:')
         print('    GEN_OPTS            General options (see below).')
@@ -341,7 +331,7 @@ def parse_args(argv_):
             args_['debug'] = True
             del argv[1:2]
         else:
-            print("Error: Unknown option: %s" % argv[1])
+            print(f"Error: Unknown option: {argv[1]}")
             sys.exit(1)
 
     args_['host'] = argv[1]
@@ -364,15 +354,15 @@ if __name__ == '__main__':
 
     if args['verbose'] in args:
         print("Using WBEM Server:")
-        print("  host: %s" % args['host'])
-        print("  username: %s" % args['username'])
+        print(f"  host: {args['host']}")
+        print(f"  username: {args['username']}")
         if args['password'] is not None:
-            print("  password: %s" % ("*" * len(args['password'])))
-        print("  maxtimeout: %s" % args['maxtimeout'])
-        print("  verbose: %s" % args['verbose'])
-        print("  stopOnErr: %s" % args['stopOnErr'])
-        print("  debug: %s" % args['debug'])
-        print("  port: %s" % args['port'])
+            print("  password: {}".format("*" * len(args['password'])))
+        print(f"  maxtimeout: {args['maxtimeout']}")
+        print(f"  verbose: {args['verbose']}")
+        print(f"  stopOnErr: {args['stopOnErr']}")
+        print(f"  debug: {args['debug']}")
+        print(f"  port: {args['port']}")
 
     # Note: unittest options are defined in separate args after
     # the url argument.
