@@ -3,11 +3,9 @@
 Test cases for _tupletree module and Unicode/XML check functions.
 """
 
-from __future__ import absolute_import, print_function
 
 import sys as _sys
 import os as _os
-import io
 import time
 import argparse as _argparse
 import datetime
@@ -16,26 +14,25 @@ import cProfile
 import locale
 from tabulate import tabulate
 from pyinstrument import Profiler
-import six
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from tests.utils import import_installed
 pywbem = import_installed('pywbem')
 from pywbem import _tupletree, __version__  # noqa: E402
 from pywbem._cliutils import SmartFormatter as _SmartFormatter  # noqa: E402
+from pywbem._tupleparse import TupleParser  # noqa: E402
 # pylint: enable=wrong-import-position, wrong-import-order, invalid-name
 # pylint: disable=use-dict-literal
 
-# In pywbem 0.13, parse_cim() changed from a function to a method:
-try:
-    from pywbem._tupleparse import parse_cim
-except ImportError:
-    from pywbem._tupleparse import TupleParser
 
-    def parse_cim(tt):
-        """Compatible parse_cim() function"""
-        tp = TupleParser()
-        return tp.parse_cim(tt)
+def parse_cim(tt):
+    """
+    Compatible parse_cim() function, since in pywbem 0.13, parse_cim() changed
+    from a function to a method.
+    """
+    tp = TupleParser()
+    return tp.parse_cim(tt)
+
 
 # default input arguments.  These are small so a user who
 # just calls the code does not fall into long run.
@@ -69,36 +66,28 @@ def _uprint(dest, text):  # pylint: disable=too-many-branches
     Otherwise, dest must be a file path, and the text is encoded to a UTF-8
     Byte sequence and is appended to the file (opening and closing the file).
     """
-    if isinstance(text, six.text_type):
-        text = text + u'\n'
-    elif isinstance(text, six.binary_type):
+    if isinstance(text, str):
+        text = text + '\n'
+    elif isinstance(text, bytes):
         text = text + b'\n'
     else:
         raise TypeError(
-            "text must be a unicode or byte string, but is {0}".
-            format(type(text)))
+            f"text must be a unicode or byte string, but is {type(text)}")
     if dest is None:
-        if six.PY2:
-            # On py2, stdout.write() requires byte strings
-            if isinstance(text, six.text_type):
-                text = text.encode(STDOUT_ENCODING, 'replace')
-        else:
-            # On py3, stdout.write() requires unicode strings
-            if isinstance(text, six.binary_type):
-                text = text.decode('utf-8')
+        if isinstance(text, bytes):
+            text = text.decode('utf-8')
         _sys.stdout.write(text)
 
-    elif isinstance(dest, (six.text_type, six.binary_type)):
-        if isinstance(text, six.text_type):
+    elif isinstance(dest, (str, bytes)):
+        if isinstance(text, str):
             kw = dict(mode='a', encoding='utf-8')
         else:
             kw = dict(mode='ab')
-        with io.open(dest, **kw) as fn:  # pylint: disable=unspecified-encoding
+        with open(dest, **kw) as fn:  # pylint: disable=unspecified-encoding
             fn.write(text)
     else:
         raise TypeError(
-            "dest must be None or a string, but is {0}".
-            format(type(text)))
+            f"dest must be None or a string, but is {type(text)}")
 
 
 class _PywbemCustomFormatter(_SmartFormatter,
@@ -119,7 +108,7 @@ class _PywbemCustomFormatter(_SmartFormatter,
     pass  # pylint: disable=unnecessary-pass
 
 
-TEMPLATE = u"""\n<VALUE.NAMEDINSTANCE>
+TEMPLATE = """\n<VALUE.NAMEDINSTANCE>
 <INSTANCENAME CLASSNAME="TST_ResponseStressTestCxx">
   <KEYBINDING NAME="Id"><KEYVALUE VALUETYPE="string">{0}</KEYVALUE>
     </KEYBINDING></INSTANCENAME><INSTANCE CLASSNAME="PERFTEST_Class" >
@@ -157,7 +146,7 @@ def build_xml_obj(number, size):
         fill_repeat = int((fill_size / len(pattern)) / 2)
 
     s1_value = pattern * fill_repeat
-    a1_value = "<VALUE>{0}</VALUE>\n".format(pattern) * fill_repeat
+    a1_value = f"<VALUE>{pattern}</VALUE>\n" * fill_repeat
 
     return TEMPLATE.format(number, pattern, s1_value, a1_value)
 
@@ -185,7 +174,7 @@ def create_xml(count=1000, size=100):
     """
     Create the xml response message
     """
-    xml = u'<?xml version="1.0" encoding="utf-8" ?>' \
+    xml = '<?xml version="1.0" encoding="utf-8" ?>' \
           '<CIM CIMVERSION="2.0" DTDVERSION="2.0">' \
           '<MESSAGE ID="1001" PROTOCOLVERSION="1.0"><SIMPLERSP>' \
           '<IMETHODRESPONSE NAME="EnumerateInstances"><IRETURNVALUE>'
@@ -235,7 +224,7 @@ def execute_with_time(xml_string, profiler):
     return time.time() - start_time
 
 
-class ExecuteTests(object):
+class ExecuteTests:
     # pylint: disable=too-few-public-methods, too-many-instance-attributes
     """
     Params class contains args parameters but lets us create new parameters
@@ -258,22 +247,16 @@ class ExecuteTests(object):
         # set logfile name if log option set. If the individual
         # option set, this will be modified
         if self.log:
-            self.logfile = "{0}_{1}_{2}_{3}.{4}".format(
-                PROFILE_OUT_PREFIX,
-                self.runid,
-                self.profiler,
-                self.file_datetime,
-                PROFILE_LOG_SUFFIX)
+            self.logfile = (
+                f"{PROFILE_OUT_PREFIX}_{self.runid}_{self.profiler}_"
+                f"{self.file_datetime}.{PROFILE_LOG_SUFFIX}")
         else:
             self.logfile = None
 
         # define a dumpfile for the cprofile save.
-        self.dumpfilename = "{0}_{1}_{2}_{3}.{4}".format(
-            PROFILE_OUT_PREFIX,
-            self.runid,
-            self.profiler,
-            self.file_datetime,
-            PROFILE_DUMP_SUFFIX)
+        self.dumpfilename = (
+            f"{PROFILE_OUT_PREFIX}_{self.runid}_{self.profiler}_"
+            f"{self.file_datetime}.{PROFILE_DUMP_SUFFIX}")
 
         # number of lines to display for cprofile output
         self.top_n_rows = args.top_n_rows
@@ -295,21 +278,14 @@ class ExecuteTests(object):
         self.cprofilesort = ["tottime", "ncalls"]
 
     def __repr__(self):
-        return "ExecuteTests(runid={0}, response_size={1} response_count={2} " \
-               "profiler={3} verbose={4}, log={5}, file_datetime={6}, " \
-               "logfile={7}, dumpfilename={8}, top_n_rows={9}, " \
-               "cprofilesort={10})".format(
-                   self.runid,
-                   self.response_size,
-                   self.response_count,
-                   self.profiler,
-                   self.verbose,
-                   self.log,
-                   self.file_datetime,
-                   self.logfile,
-                   self.dumpfilename,
-                   self.top_n_rows,
-                   self.cprofilesort)
+        return (
+            f"ExecuteTests(runid={self.runid}, "
+            f"response_size={self.response_size} "
+            f"response_count={self.response_count} "
+            f"profiler={self.profiler} verbose={self.verbose}, "
+            f"log={self.log}, file_datetime={self.file_datetime}, "
+            f"logfile={self.logfile}, dumpfilename={self.dumpfilename}, "
+            f"top_n_rows={self.top_n_rows}, cprofilesort={self.cprofilesort})")
 
     def execute_raw_tests(self, profiler=None):
         """
@@ -326,7 +302,7 @@ class ExecuteTests(object):
                        int(avg_resp_size),
                        response_count,
                        len(xml),
-                       "{0:5.2f}".format(execution_time),
+                       f"{execution_time:5.2f}",
                        int(response_count / execution_time))
                 table_rows.append(row)
         return table_rows
@@ -348,8 +324,8 @@ class ExecuteTests(object):
         try:
             ps.dump_stats(self.dumpfilename)
         except Exception as ex:  # pylint: disable=broad-except
-            print('cProfiler dump stats exception %s %s. Ignored' %
-                  (ex.__class__.__name__, ex))
+            print(f'cProfiler dump stats exception {ex.__class__.__name__} '
+                  f'{ex}. Ignored')
 
         # modify stats for display and output to stdout
         ps.strip_dirs()
@@ -358,7 +334,7 @@ class ExecuteTests(object):
 
         # if dest defined, output to file defined by dest
         if self.logfile:
-            with io.open(self.logfile, 'w', encoding='utf-8') as stream:
+            with open(self.logfile, 'w', encoding='utf-8') as stream:
                 ps = pstats.Stats(profiler, stream=stream)
                 ps.strip_dirs()
                 ps.sort_stats(*self.cprofilesort)
@@ -393,8 +369,8 @@ class ExecuteTests(object):
         elif self.profiler == 'cprofile':
             table_rows = self.execute_cprofile_tests()
         else:
-            raise RuntimeError('profiler arg %s invalid. '
-                               'Should never occur' % self.profiler)
+            raise RuntimeError(
+                f'profiler arg {self.profiler} invalid. Should never occur')
 
         # build and output results report
         header = ["Exp inst\nsize",
@@ -403,12 +379,11 @@ class ExecuteTests(object):
                   "XML\nsize",
                   "Parse time\nsec.",
                   "Instances\nper sec"]
-        title = 'Results: profile={0}, response_counts={1},\n   ' \
-                'response-sizes={2}, runid={3} {4}'.format(self.profiler,
-                                                           self.response_count,
-                                                           self.response_size,
-                                                           self.runid,
-                                                           self.file_datetime)
+        title = (
+            f'Results: profiler={self.profiler}, '
+            f'response_counts={self.response_count},\n   '
+            f'response-sizes={self.response_size}, runid={self.runid} '
+            f'{self.file_datetime}')
         table = tabulate(table_rows, header, tablefmt=self.tbl_output_format)
 
         # print statistics to terminal
@@ -438,27 +413,19 @@ def execute_individual_tests(args):
             # define a dump file name for each execution
             tests.response_count = [response_count]
             tests.response_size = [response_size]
-            tests.dumpfilename = "{0}_{1}_{2}_{3}_{4}_{5}.{6}".format(
-                PROFILE_OUT_PREFIX,
-                tests.runid,
-                args.profiler,
-                tests.file_datetime,
-                response_count,
-                response_size,
-                PROFILE_DUMP_SUFFIX)
+            tests.dumpfilename = (
+                f"{PROFILE_OUT_PREFIX}_{tests.runid}_{args.profiler}_"
+                f"{tests.file_datetime}_{response_count}_{response_size}."
+                f"{PROFILE_DUMP_SUFFIX}")
 
             # If a log destination is defined modify the dump file name
             # for each individual  test suffixes the name with the
             # response_size and response_count
             if args.log:
-                tests.logfile = "{0}_{1}_{2}_{3}_{4}_{5}.{6}".format(
-                    PROFILE_OUT_PREFIX,
-                    tests.runid,
-                    args.profiler,
-                    tests.file_datetime,
-                    response_count,
-                    response_size,
-                    PROFILE_LOG_SUFFIX)
+                tests.logfile = (
+                    f"{PROFILE_OUT_PREFIX}_{tests.runid}_{args.profiler}_"
+                    f"{tests.file_datetime}_{response_count}_{response_size}."
+                    f"{PROFILE_LOG_SUFFIX}")
 
             tests.execute_tests()
 
@@ -490,20 +457,20 @@ the execution time for each test.
 
 NOTE: Running with a profiler heavily affects the runtime.
 """
-    epilog = """
+    epilog = f"""
 Examples:
-  %s
+  {prog}
 
      Execute a minimal test with default input arguments and display time to
      execute. It does not use either of the profilers.
 
-  %s  -p cprofile --response-count 10000 20000 \\
+  {prog}  -p cprofile --response-count 10000 20000 \\
     --response-size 100 1000
 
      Execute the test for all combinations of response counts of 10,000 and
      20,000 and for response sizes of 500 and 1000 bytes using cprofile
      profiler to generate and output a profile of the operation.
-""" % (prog, prog)  # noqa: E501
+"""  # noqa: E501
 # pylint: enable=line-too-long
 
     argparser = _argparse.ArgumentParser(
@@ -525,7 +492,7 @@ Examples:
              '   * `cprofile` uses cProfile and generates a table of\n'
              '     counts.\n'
              '   * `none` runs without profiler.\n'
-             ' Default: %s' % "none")
+             ' Default: none')
 
     tests_arggroup.add_argument(
         '-c', '--response-count', dest='response_count', nargs='+',
@@ -536,7 +503,7 @@ Examples:
              'integers. The test will be executed for each\n'
              'response-size and each value defined. The format is:\n'
              '   -c 1000 10000 100000\n'
-             'Default: %s' % DEFAULT_RESPONSE_COUNT)
+             f'Default: {DEFAULT_RESPONSE_COUNT}')
 
     tests_arggroup.add_argument(
         '-s', '--response-size', dest='response_size', nargs='+',
@@ -548,7 +515,7 @@ Examples:
              'executed for the combination of each response-count\n'
              'and each value provided. The format is:\n'
              '   -s 100 200 300\n'
-             'Default: %s' % DEFAULT_RESPONSE_SIZE)
+             f'Default: {DEFAULT_RESPONSE_SIZE}')
 
     tests_arggroup.add_argument(
         '-n', '--top-n-rows', dest='top_n_rows',
@@ -556,7 +523,7 @@ Examples:
         action='store', default=DEFAULT_TOP_N_ROWS,
         help='R|The number of rows of profile data for the cprofile\n'
              'display. This is the top n tottime results.\n'
-             'Default: %s' % DEFAULT_TOP_N_ROWS)
+             f'Default: {DEFAULT_TOP_N_ROWS}')
 
     tests_arggroup.add_argument(
         '-r', '--runid', dest='runid',
@@ -564,7 +531,7 @@ Examples:
         action='store', default=DEFAULT_RUNID,
         help='R|A string that is concatenated into each filename\n'
              'created by the script. It is suffixed with pywbem version.\n'
-             'Default: %s' % DEFAULT_RUNID)
+             f'Default: {DEFAULT_RUNID}')
 
     tests_arggroup.add_argument(
         '-i', '--individual', dest='individual',
@@ -595,7 +562,7 @@ Examples:
 
     if args.top_n_rows <= 0:
         argparser.error("top-n-rows must be postive integer. "
-                        "{0} not allowed".format(args.top_n_rows))
+                        f"{args.top_n_rows} not allowed")
 
     return args
 
@@ -607,10 +574,10 @@ def main():
     """
     args = parse_args()
 
-    print('Starting profiler={0}, response-count={1} response-size={2} '
-          'runid={3} log={4}'.format(args.profiler, args.response_count,
-                                     args.response_size, args.runid,
-                                     args.log))
+    print(f'Starting profiler={args.profiler}, '
+          f'response-count={args.response_count} '
+          f'response-size={args.response_size} '
+          f'runid={args.runid} log={args.log}')
 
     if args.individual:
         execute_individual_tests(args)
