@@ -2,14 +2,13 @@
 Unit test cases for _cim_http.py
 """
 
-from __future__ import absolute_import
-
 import re
+
 import requests
 import urllib3
 import pytest
 
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -106,9 +105,9 @@ TESTCASES_PARSE_URL = [
                 url='myhost:5000',
                 allow_defaults=True,
             ),
-            exp_scheme='{scheme}'.format(scheme=DEFAULT_SCHEME),
+            exp_scheme=f'{DEFAULT_SCHEME}',
             exp_hostport='myhost:5000',
-            exp_url='{scheme}://myhost:5000'.format(scheme=DEFAULT_SCHEME),
+            exp_url=f'{DEFAULT_SCHEME}://myhost:5000',
         ),
         None, None, True
     ),
@@ -133,8 +132,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='https',
-            exp_hostport='myhost:{port}'.format(port=DEFAULT_PORT_HTTPS),
-            exp_url='https://myhost:{port}'.format(port=DEFAULT_PORT_HTTPS),
+            exp_hostport=f'myhost:{DEFAULT_PORT_HTTPS}',
+            exp_url=f'https://myhost:{DEFAULT_PORT_HTTPS}',
         ),
         None, None, True
     ),
@@ -159,8 +158,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'myhost:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://myhost:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -197,10 +196,9 @@ TESTCASES_PARSE_URL = [
                 url='http',
                 allow_defaults=True,
             ),
-            exp_scheme='{scheme}'.format(scheme=DEFAULT_SCHEME),
-            exp_hostport='http:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='{scheme}://http:{port}'.
-            format(scheme=DEFAULT_SCHEME, port=DEFAULT_PORT_HTTP),
+            exp_scheme=f'{DEFAULT_SCHEME}',
+            exp_hostport=f'http:{DEFAULT_PORT_HTTP}',
+            exp_url=f'{DEFAULT_SCHEME}://http:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -211,10 +209,9 @@ TESTCASES_PARSE_URL = [
                 url='https',
                 allow_defaults=True,
             ),
-            exp_scheme='{scheme}'.format(scheme=DEFAULT_SCHEME),
-            exp_hostport='https:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='{scheme}://https:{port}'.
-            format(scheme=DEFAULT_SCHEME, port=DEFAULT_PORT_HTTP),
+            exp_scheme=f'{DEFAULT_SCHEME}',
+            exp_hostport=f'https:{DEFAULT_PORT_HTTP}',
+            exp_url=f'{DEFAULT_SCHEME}://https:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -252,8 +249,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'myhost:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://myhost:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -265,8 +262,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://myhost:{port}'.format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'myhost:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://myhost:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -304,8 +301,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='9.10.11.12:{port}'.format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://9.10.11.12:{port}'.format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'9.10.11.12:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://9.10.11.12:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -316,11 +313,9 @@ TESTCASES_PARSE_URL = [
                 url='[2001:db8::7348]',
                 allow_defaults=True,
             ),
-            exp_scheme='{scheme}'.format(scheme=DEFAULT_SCHEME),
-            exp_hostport='[2001:db8::7348]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='{scheme}://[2001:db8::7348]:{port}'.
-            format(scheme=DEFAULT_SCHEME, port=DEFAULT_PORT_HTTP),
+            exp_scheme=f'{DEFAULT_SCHEME}',
+            exp_hostport=f'[2001:db8::7348]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'{DEFAULT_SCHEME}://[2001:db8::7348]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -332,10 +327,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='[2001:db8::7348]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://[2001:db8::7348]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'[2001:db8::7348]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://[2001:db8::7348]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -348,10 +341,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='[2001:db8::7348-1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://[2001:db8::7348-1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'[2001:db8::7348-1]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://[2001:db8::7348-1]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -364,10 +355,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='[2001:db8::7348-1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://[2001:db8::7348-1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'[2001:db8::7348-1]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://[2001:db8::7348-1]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -380,10 +369,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='[2001:db8::7348-eth1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://[2001:db8::7348-eth1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'[2001:db8::7348-eth1]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://[2001:db8::7348-eth1]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -396,10 +383,8 @@ TESTCASES_PARSE_URL = [
                 allow_defaults=True,
             ),
             exp_scheme='http',
-            exp_hostport='[2001:db8::7348-eth1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
-            exp_url='http://[2001:db8::7348-eth1]:{port}'.
-            format(port=DEFAULT_PORT_HTTP),
+            exp_hostport=f'[2001:db8::7348-eth1]:{DEFAULT_PORT_HTTP}',
+            exp_url=f'http://[2001:db8::7348-eth1]:{DEFAULT_PORT_HTTP}',
         ),
         None, None, True
     ),
@@ -480,10 +465,9 @@ TESTCASES_PARSE_URL = [
                 url='2001:db8::7348:1234',
                 allow_defaults=True,
             ),
-            exp_scheme='{scheme}'.format(scheme=DEFAULT_SCHEME),
+            exp_scheme=f'{DEFAULT_SCHEME}',
             exp_hostport='[2001:db8::7348]:1234',
-            exp_url='{scheme}://[2001:db8::7348]:1234'.
-            format(scheme=DEFAULT_SCHEME),
+            exp_url=f'{DEFAULT_SCHEME}://[2001:db8::7348]:1234',
         ),
         None, None, True
     ),
@@ -606,6 +590,7 @@ TESTCASES_PARSE_URL = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_PARSE_URL)
 @simplified_test_function
+@log_entry_exit
 def test_parse_url(
         testcase, func_kwargs, exp_scheme, exp_hostport, exp_url):
     """
@@ -798,8 +783,8 @@ TESTCASES_PYWBEM_REQUESTS_EXCEPTION = [
                         reason=urllib3.exceptions.ReadTimeoutError(
                             pool=DUMMY_POOL,
                             url='http://dummy',
-                            message="Read timed out. (read timeout={})".
-                            format(HTTP_CONNECT_TIMEOUT)))),
+                            message="Read timed out. (read timeout="
+                            f"{HTTP_CONNECT_TIMEOUT})"))),
                 conn=DUMMY_CONN_USING_HTTP,
             ),
             exp_exc_type=pywbem.ConnectionError,
@@ -872,6 +857,7 @@ TESTCASES_PYWBEM_REQUESTS_EXCEPTION = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_PYWBEM_REQUESTS_EXCEPTION)
 @simplified_test_function
+@log_entry_exit
 def test_pywbem_requests_exception(
         testcase, func_kwargs, exp_exc_type, exp_pattern):
     """
@@ -983,6 +969,7 @@ TESTCASES_MAX_REPR = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_MAX_REPR)
 @simplified_test_function
+@log_entry_exit
 def test_max_repr(testcase, func_kwargs, exp_repr):
     """
     Test function for _cim_http.max_repr()
@@ -1094,6 +1081,7 @@ TESTCASES_GET_CIMOBJECT_HEADER = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_GET_CIMOBJECT_HEADER)
 @simplified_test_function
+@log_entry_exit
 def test_get_cimobject_header(testcase, obj, exp_result):
     """
     Test function for _cim_http.get_cimobject_header()
