@@ -1,21 +1,18 @@
 #!/usr/bin/env python
-#
 
 """
 Unittest functions in _cim_operations.
 """
 
-from __future__ import print_function, absolute_import
-
 import sys
 import os
-import io
 import re
+
 import pytest
 
 from ...utils import skip_if_moftab_regenerated
 from ..utils.dmtf_mof_schema_def import install_test_dmtf_schema
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 from ..utils.unittest_extensions import assert_copy
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
@@ -278,7 +275,7 @@ TESTCASES_INIT_WBEMCONNECTION = [
 ]
 
 
-class TestCreateConnection(object):
+class TestCreateConnection:
     """
     Test construction of WBEMConnection and those functions that do not
     depend on actually creating a connection
@@ -287,6 +284,7 @@ class TestCreateConnection(object):
     @pytest.mark.parametrize(
         'desc, files, init_kwargs, exp_attrs, exp_exc, exp_exc_regex',
         TESTCASES_INIT_WBEMCONNECTION)
+    @log_entry_exit
     def test_init(self, desc, files, init_kwargs, exp_attrs, exp_exc,
                   exp_exc_regex):
         # pylint: disable=no-self-use,unused-argument
@@ -297,7 +295,7 @@ class TestCreateConnection(object):
         try:
             for fname in files:
                 # create empty file
-                with io.open(fname, 'a', encoding='utf-8'):
+                with open(fname, 'a', encoding='utf-8'):
                     pass
 
             if exp_exc is not None:
@@ -338,6 +336,7 @@ class TestCreateConnection(object):
             ('last_request_len', 7),
             ('last_reply_len', 7),
         ])
+    @log_entry_exit
     def test_attrs_readonly(self, attr_name, value):
         # pylint: disable=no-self-use
         """
@@ -362,12 +361,14 @@ class TestCreateConnection(object):
             (dict(default_namespace=DEFAULT_NAMESPACE), DEFAULT_NAMESPACE),
             (dict(default_namespace='blah'), 'blah'),
         ])
+    @log_entry_exit
     def test_init_default_namespace(self, kwargs, exp_default_namespace):
         # pylint: disable=no-self-use
         """Test creation of wbem connection with default_namespace values"""
         conn = WBEMConnection('http://localhost', ('name', 'pw'), **kwargs)
         assert conn.default_namespace == exp_default_namespace
 
+    @log_entry_exit
     def test_namespace_slashes_init(self):  # pylint: disable=no-self-use
         """Test stripping of leading and trailing slashes in default namespace
         of wbem connection when initializing"""
@@ -375,6 +376,7 @@ class TestCreateConnection(object):
                               default_namespace='//root/blah//')
         assert conn.default_namespace == 'root/blah'
 
+    @log_entry_exit
     def test_namespace_slashes_set(self):  # pylint: disable=no-self-use
         """Test stripping of leading and trailing slashes in default namespace
         of wbem connection when setting the attribute"""
@@ -383,6 +385,7 @@ class TestCreateConnection(object):
         conn.default_namespace = '//root/blah//'
         assert conn.default_namespace == 'root/blah'
 
+    @log_entry_exit
     def test_add_operation_recorder(self):  # pylint: disable=no-self-use
         """Test addition of an operation recorder"""
         conn = WBEMConnection('http://localhost')
@@ -390,6 +393,7 @@ class TestCreateConnection(object):
         # pylint: disable=protected-access
         assert len(conn._operation_recorders) == 1
 
+    @log_entry_exit
     def test_add_operation_recorders(self):  # pylint: disable=no-self-use
         """Test addition of multiple operation recorders"""
         conn = WBEMConnection('http://localhost')
@@ -402,6 +406,7 @@ class TestCreateConnection(object):
         tcr_file.close()
         os.remove(tcr_fn)
 
+    @log_entry_exit
     def test_add_same_twice(self):  # pylint: disable=no-self-use
         """
         Test addition of same recorder twice. This not allowed so
@@ -415,6 +420,7 @@ class TestCreateConnection(object):
         with pytest.raises(ValueError):
             conn.add_operation_recorder(LogOperationRecorder('fake_conn_id'))
 
+    @log_entry_exit
     def test_stats_enabled(self):  # pylint: disable=no-self-use
         """
         Test the property stats_enabled setter
@@ -426,6 +432,7 @@ class TestCreateConnection(object):
         conn.stats_enabled = False
         assert conn.stats_enabled is False
 
+    @log_entry_exit
     def test_operation_recorder_enabled(self):  # pylint: disable=no-self-use
         """
         Test the property operation_recorder enabled setter
@@ -438,6 +445,7 @@ class TestCreateConnection(object):
         conn.operation_recorder_enabled = True
         assert conn.operation_recorder_enabled is True
 
+    @log_entry_exit
     def test_close(self):  # pylint: disable=no-self-use
         """
         Test closing a connection once.
@@ -447,6 +455,7 @@ class TestCreateConnection(object):
         conn.close()
         assert conn.session is None
 
+    @log_entry_exit
     def test_close_twice(self):  # pylint: disable=no-self-use
         """
         Test closing a connection twice.
@@ -459,6 +468,7 @@ class TestCreateConnection(object):
             exc = exc_info.value
             assert re.match(r'is closed', str(exc))
 
+    @log_entry_exit
     def test_close_imethod(self):  # pylint: disable=no-self-use
         """
         Test closing a connection and invoking an intrinsic operation.
@@ -471,6 +481,7 @@ class TestCreateConnection(object):
             exc = exc_info.value
             assert re.match(r'is closed', str(exc))
 
+    @log_entry_exit
     def test_close_method(self):  # pylint: disable=no-self-use
         """
         Test closing a connection and invoking a CIM method.
@@ -483,6 +494,7 @@ class TestCreateConnection(object):
             exc = exc_info.value
             assert re.match(r'is closed', str(exc))
 
+    @log_entry_exit
     def test_close_export(self):  # pylint: disable=no-self-use
         """
         Test closing a connection and invoking an export operation.
@@ -496,6 +508,7 @@ class TestCreateConnection(object):
             exc = exc_info.value
             assert re.match(r'is closed', str(exc))
 
+    @log_entry_exit
     def test_context_manager(self):  # pylint: disable=no-self-use
         """
         Test the use of WBEMConnection as a context manager.
@@ -507,6 +520,7 @@ class TestCreateConnection(object):
         assert conn.session is None
 
 
+@log_entry_exit
 def test_conn_set_timeout():
     """
     Test setting the 'timeout' property of WBEMConnection.
@@ -517,7 +531,7 @@ def test_conn_set_timeout():
     assert conn.timeout == 25
 
 
-class TestGetRsltParams(object):
+class TestGetRsltParams:
     """Test WBEMConnection._get_rslt_params method."""
 
     @pytest.mark.parametrize(
@@ -526,15 +540,16 @@ class TestGetRsltParams(object):
         # enumctxt input, eos input, expected eos, expected exception type
         'ec, eos, eos_exp, exctype_exp', [
             # following are successul returns
-            [u'contextblah', u'False', False, None],  # normal enumctxt rtn
-            ["", u'True', True, None],                # eos true, enmctxt empty
-            [None, u'True', True, None],              # eos true, enmctxt None
-            [u'contextblah', u'True', True, None],    # eos tru, cts with value
+            ['contextblah', 'False', False, None],  # normal enumctxt rtn
+            ["", 'True', True, None],                # eos true, enmctxt empty
+            [None, 'True', True, None],              # eos true, enmctxt None
+            ['contextblah', 'True', True, None],    # eos tru, cts with value
             # following are exceptions
             [None, None, None, ParseError],      # no values in eos or enumctxt
-            [None, u'False', None, ParseError],  # no value in ec and eos False
+            [None, 'False', None, ParseError],  # no value in ec and eos False
         ]
     )
+    @log_entry_exit
     def test_with_params(self, irval, ec, eos, eos_exp, exctype_exp):
         # pylint: disable=no-self-use,protected-access
         """
@@ -543,9 +558,9 @@ class TestGetRsltParams(object):
         """
         conn = WBEMConnection('http://localhost')
         result = [
-            (u'IRETURNVALUE', {}, irval),
-            (u'EnumerationContext', None, ec),
-            (u'EndOfSequence', None, eos)
+            ('IRETURNVALUE', {}, irval),
+            ('EnumerationContext', None, ec),
+            ('EndOfSequence', None, eos)
         ]
 
         if exctype_exp:
@@ -563,6 +578,7 @@ class TestGetRsltParams(object):
             ecs = None if eos_exp is True else (ec, 'root/blah')
             assert result == (irval, eos_exp, ecs)
 
+    @log_entry_exit
     def test_missing(self):
         # pylint: disable=no-self-use
         """
@@ -571,7 +587,7 @@ class TestGetRsltParams(object):
         """
         conn = WBEMConnection('http://localhost')
         result = [
-            (u'IRETURNVALUE', {}, {})
+            ('IRETURNVALUE', {}, {})
         ]
 
         with pytest.raises(ParseError):
@@ -697,6 +713,7 @@ TESTCASES_IS_SUBCLASS = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_IS_SUBCLASS)
 @simplified_test_function
+@log_entry_exit
 def test_is_subclass(testcase, init_args, exp_attrs):
     # pylint: disable=unused-argument
     """
@@ -747,7 +764,7 @@ TESTCASES_REQUEST_INVALID_PARAMS = [
     # * condition: Boolean condition for testcase to run, or 'pdb' for
     #   debugger
     (
-        "Test invalid invokemethod objectname (integer)",
+        "Test invalid invokemethod objectname (int)",
         dict(
             init_kwargs={},
             method='invokemethod',
@@ -1005,6 +1022,7 @@ TESTCASES_REQUEST_INVALID_PARAMS = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_REQUEST_INVALID_PARAMS)
 @simplified_test_function
+@log_entry_exit
 def test_request_invalid_params(testcase, init_kwargs, method, args, kwargs):
     """Execute the defined method expecting exception"""
 
@@ -1038,14 +1056,16 @@ def test_request_invalid_params(testcase, init_kwargs, method, args, kwargs):
         _ = list(conn.IterEnumerateInstancePaths(*args, **kwargs))
 
     else:
-        assert False, "Test failed. Incomplete. "  \
-            "method {0} not found".format(method)
+        assert False, (
+            "Test failed. Incomplete. "
+            f"method {method} not found")
 
     # Ensure that exceptions raised in the remainder of this function
     # are not mistaken as expected exceptions
     assert testcase.exp_exc_types is None
 
 
+@log_entry_exit
 def test_close():
     """
     Test WBEMConnection.close().
@@ -1219,6 +1239,7 @@ TESTCASES_COPY_WBEMCONNECTION = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_COPY_WBEMCONNECTION)
 @simplified_test_function
+@log_entry_exit
 def test_copy_conn(
         testcase, files, init_kwargs, set_debug, add_recorder, enable_recorder,
         enable_statistics, perform_operation):
@@ -1227,11 +1248,11 @@ def test_copy_conn(
     try:
         for fname in files:
             # create empty file
-            with io.open(fname, 'a', encoding='utf-8'):
+            with open(fname, 'a', encoding='utf-8'):
                 pass
 
         # pylint: disable=consider-using-with
-        dev_null = io.open(DEV_NULL, 'a', encoding='utf-8')
+        dev_null = open(DEV_NULL, 'a', encoding='utf-8')
 
         conn = WBEMConnection(**init_kwargs)
 
@@ -1391,7 +1412,7 @@ TESTCASES_WBEMCONNECTION_ERROR = [
 ]
 
 
-class TestConnectionError(object):  # pylint: disable=too-few-public-methods
+class TestConnectionError:  # pylint: disable=too-few-public-methods
     """
     Test construction of WBEMConnection and error exception when connection
     is executed with a function that communicates with the server.
@@ -1402,6 +1423,7 @@ class TestConnectionError(object):  # pylint: disable=too-few-public-methods
     @pytest.mark.parametrize(
         'desc, init_kwargs, exp_exc, exp_exc_regex',
         TESTCASES_WBEMCONNECTION_ERROR)
+    @log_entry_exit
     def test_init(self, desc, init_kwargs, exp_exc, exp_exc_regex):
         # pylint: disable=no-self-use,unused-argument
         """
