@@ -4,15 +4,16 @@
 Test CIM types.
 """
 
-from __future__ import absolute_import, print_function
-
 import re
 from datetime import timedelta, datetime
-import pytz
-import pytest
-import six
 
-from ..utils.pytest_extensions import simplified_test_function
+try:
+    import zoneinfo
+except ImportError:
+    from backports import zoneinfo
+import pytest
+
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -41,27 +42,27 @@ from pywbem import CIMType, CIMInt, CIMFloat, Uint8, Uint16, Uint32, Uint64, \
     # )
     (
         None,
-        u'None',
+        'None',
         None,
     ),
     (
-        u'foo',
-        u'foo',
+        'foo',
+        'foo',
         None,
     ),
     (
         b'foo',
-        u'foo',
+        'foo',
         None,
     ),
     (
         42,
-        u'42',
+        '42',
         None,
     ),
     (
         Char16('foo'),
-        u'foo',
+        'foo',
         None,
     ),
 ], scope='module')
@@ -70,24 +71,28 @@ def char16_init_tuple(request):
     return request.param
 
 
+@log_entry_exit
 def test_char16_class_attrs_class():  # pylint: disable=invalid-name
     """Test class attrs via class level"""
     assert Char16.cimtype == 'char16'
 
 
+@log_entry_exit
 def test_char16_class_attrs_inst():
     """Test class attrs via instance level"""
     obj = Char16('foo')
     assert obj.cimtype == 'char16'
 
 
+@log_entry_exit
 def test_char16_inheritance():
     """Test inheritance"""
     obj = Char16('foo')
-    assert isinstance(obj, six.text_type)
+    assert isinstance(obj, str)
     assert isinstance(obj, CIMType)
 
 
+@log_entry_exit
 def test_char16_init(char16_init_tuple):
     """Test initialization from all input types using
        char16_init_tuple pytest.fixture.
@@ -105,6 +110,7 @@ def test_char16_init(char16_init_tuple):
         assert obj is not in_str
 
 
+@log_entry_exit
 def test_char16_repr(char16_init_tuple):
     """
     Test repr(CIMDateTime) from all input types using
@@ -123,6 +129,7 @@ def test_char16_repr(char16_init_tuple):
     repr(obj)
 
 
+@log_entry_exit
 def test_char16_str(char16_init_tuple):
     """
     Test str(CIMDateTime) from all input types using
@@ -150,9 +157,9 @@ def test_char16_str(char16_init_tuple):
 
     # Each list item is a tuple of:
     # - obj_type (type): CIM integer data type (e.g. Uint8).
-    # - exp_cimtype (string): Expected value of cimtype class attribute for
+    # - exp_cimtype (str): Expected value of cimtype class attribute for
     #   this CIM data type.
-    # - exp_minvalue (integer): Expected value of minvalue class attribute for
+    # - exp_minvalue (int): Expected value of minvalue class attribute for
     #   this CIM data type.
     # - exp_maxvalue (): Expected value of maxvalue class attribute for
     #   this CIM data type.
@@ -172,6 +179,7 @@ def integer_tuple(request):
     return request.param
 
 
+@log_entry_exit
 def test_integer_class_attrs_class(integer_tuple):
     """Test class attrs via class level"""
     # pylint: disable=redefined-outer-name
@@ -181,6 +189,7 @@ def test_integer_class_attrs_class(integer_tuple):
     assert obj_type.maxvalue == exp_maxvalue
 
 
+@log_entry_exit
 def test_integer_class_attrs_inst(integer_tuple):
     """Test class attrs via instance level"""
     # pylint: disable=redefined-outer-name
@@ -191,6 +200,7 @@ def test_integer_class_attrs_inst(integer_tuple):
     assert obj.maxvalue == exp_maxvalue
 
 
+@log_entry_exit
 def test_integer_inheritance(integer_tuple):
     """Test inheritance"""
     # pylint: disable=redefined-outer-name
@@ -202,6 +212,7 @@ def test_integer_inheritance(integer_tuple):
     assert not isinstance(obj, CIMFloat)
 
 
+@log_entry_exit
 def test_integer_init_int(integer_tuple):
     """Test initialization from integer value"""
     # pylint: disable=redefined-outer-name
@@ -210,6 +221,7 @@ def test_integer_init_int(integer_tuple):
     assert obj == 42
 
 
+@log_entry_exit
 def test_integer_init_str(integer_tuple):
     """Test initialization from string value"""
     # pylint: disable=redefined-outer-name
@@ -218,6 +230,7 @@ def test_integer_init_str(integer_tuple):
     assert obj == 42
 
 
+@log_entry_exit
 def test_integer_init_str_base10(integer_tuple):
     """Test initialization from string value with base 10"""
     # pylint: disable=redefined-outer-name
@@ -226,6 +239,7 @@ def test_integer_init_str_base10(integer_tuple):
     assert obj == 42
 
 
+@log_entry_exit
 def test_integer_init_str_base16(integer_tuple):
     """Test initialization from string value with base 16"""
     # pylint: disable=redefined-outer-name
@@ -234,6 +248,7 @@ def test_integer_init_str_base16(integer_tuple):
     assert obj == 42
 
 
+@log_entry_exit
 def test_integer_init_minimum(integer_tuple):
     """Test initialization from integer value at minimum"""
     # pylint: disable=redefined-outer-name
@@ -243,6 +258,7 @@ def test_integer_init_minimum(integer_tuple):
     assert obj == exp_minvalue
 
 
+@log_entry_exit
 def test_integer_init_maximum(integer_tuple):
     """Test initialization from integer value at maximum"""
     # pylint: disable=redefined-outer-name
@@ -252,6 +268,7 @@ def test_integer_init_maximum(integer_tuple):
     assert obj == exp_maxvalue
 
 
+@log_entry_exit
 def test_integer_init_too_low(integer_tuple):
     """Test initialization from integer value below minimum"""
     # pylint: disable=redefined-outer-name
@@ -265,6 +282,7 @@ def test_integer_init_too_low(integer_tuple):
         raise AssertionError("ValueError was not raised.")
 
 
+@log_entry_exit
 def test_integer_init_too_high(integer_tuple):
     """Test initialization from integer value above maximum"""
     # pylint: disable=redefined-outer-name
@@ -287,7 +305,7 @@ def test_integer_init_too_high(integer_tuple):
 
     # Each list item is a tuple of:
     # - obj_type (type): CIM real data type (e.g. Real32).
-    # - exp_cimtype (string): Expected value of cimtype class attribute for
+    # - exp_cimtype (str): Expected value of cimtype class attribute for
     #   this CIM data type.
 
     # (obj_type, exp_cimtype)
@@ -299,6 +317,7 @@ def real_tuple(request):
     return request.param
 
 
+@log_entry_exit
 def test_real_class_attrs_class(real_tuple):
     """Test class attrs via class level using real_tuple fixture"""
     # pylint: disable=redefined-outer-name
@@ -306,6 +325,7 @@ def test_real_class_attrs_class(real_tuple):
     assert obj_type.cimtype == exp_cimtype
 
 
+@log_entry_exit
 def test_real_class_attrs_inst(real_tuple):
     """Test class attrs via instance level using real_tuple fixture"""
     # pylint: disable=redefined-outer-name
@@ -314,6 +334,7 @@ def test_real_class_attrs_inst(real_tuple):
     assert obj.cimtype == exp_cimtype
 
 
+@log_entry_exit
 def test_real_inheritance(real_tuple):
     """Test inheritance  using real_tuple fixture"""
     # pylint: disable=redefined-outer-name
@@ -325,6 +346,7 @@ def test_real_inheritance(real_tuple):
     assert not isinstance(obj, CIMInt)
 
 
+@log_entry_exit
 def test_real_init_float(real_tuple):
     """Test initialization from floating point value"""
     # pylint: disable=redefined-outer-name
@@ -333,6 +355,7 @@ def test_real_init_float(real_tuple):
     assert obj == 42.0
 
 
+@log_entry_exit
 def test_real_init_str(real_tuple):
     """Test initialization from string value using real_tuple fixture"""
     # pylint: disable=redefined-outer-name
@@ -349,22 +372,23 @@ def test_real_init_str(real_tuple):
 
     # Each list item is a tuple of:
     # (obj_type, init_arg, exp_str, exp_repr_pattern)
-    (Uint8, 42, u'42', r'^Uint8\(.*, 42\)'),
-    (Uint16, 42, u'42', r'^Uint16\(.*, 42\)'),
-    (Uint32, 42, u'42', r'^Uint32\(.*, 42\)'),
-    (Uint64, 42, u'42', r'^Uint64\(.*, 42\)'),
-    (Sint8, -42, u'-42', r'^Sint8\(.*, -42\)'),
-    (Sint16, -42, u'-42', r'^Sint16\(.*, -42\)'),
-    (Sint32, -42, u'-42', r'^Sint32\(.*, -42\)'),
-    (Sint64, -42, u'-42', r'^Sint64\(.*, -42\)'),
-    (Real32, -42.1, u'-42.1', r'^Real32\(.*, -42.1\)'),
-    (Real64, -42.1, u'-42.1', r'^Real64\(.*, -42.1\)'),
+    (Uint8, 42, '42', r'^Uint8\(.*, 42\)'),
+    (Uint16, 42, '42', r'^Uint16\(.*, 42\)'),
+    (Uint32, 42, '42', r'^Uint32\(.*, 42\)'),
+    (Uint64, 42, '42', r'^Uint64\(.*, 42\)'),
+    (Sint8, -42, '-42', r'^Sint8\(.*, -42\)'),
+    (Sint16, -42, '-42', r'^Sint16\(.*, -42\)'),
+    (Sint32, -42, '-42', r'^Sint32\(.*, -42\)'),
+    (Sint64, -42, '-42', r'^Sint64\(.*, -42\)'),
+    (Real32, -42.1, '-42.1', r'^Real32\(.*, -42.1\)'),
+    (Real64, -42.1, '-42.1', r'^Real64\(.*, -42.1\)'),
 ], scope='module')
 def number_str_repr_tuple(request):
     """Utility function to return param from request"""
     return request.param
 
 
+@log_entry_exit
 def test_number_str(number_str_repr_tuple):
     # pylint: disable=redefined-outer-name
     """Test __str__() for a number"""
@@ -377,6 +401,7 @@ def test_number_str(number_str_repr_tuple):
     assert act_str == exp_str
 
 
+@log_entry_exit
 def test_number_repr(number_str_repr_tuple):
     # pylint: disable=redefined-outer-name
     """Test __repr__() for a number"""
@@ -823,17 +848,20 @@ def datetime_init_tuple(request):
     return request.param
 
 
+@log_entry_exit
 def test_datetime_class_attrs_class():  # pylint: disable=invalid-name
     """Test class attrs via class level"""
     assert CIMDateTime.cimtype == 'datetime'
 
 
+@log_entry_exit
 def test_datetime_class_attrs_inst():
     """Test class attrs via instance level"""
     obj = CIMDateTime('00000000000000.000000:000')
     assert obj.cimtype == 'datetime'
 
 
+@log_entry_exit
 def test_datetime_inheritance():
     """Test inheritance"""
     obj = CIMDateTime('00000000000000.000000:000')
@@ -843,6 +871,7 @@ def test_datetime_inheritance():
     assert not isinstance(obj, CIMInt)
 
 
+@log_entry_exit
 def test_datetime_init(datetime_init_tuple):
     """Test initialization from all input types using
        datetime_init_tuple pytest.fixture.
@@ -870,6 +899,7 @@ def test_datetime_init(datetime_init_tuple):
         assert str(obj) == exp_str
 
 
+@log_entry_exit
 def test_datetime_repr(datetime_init_tuple):
     """
     Test repr(CIMDateTime) from all input types using
@@ -888,6 +918,7 @@ def test_datetime_repr(datetime_init_tuple):
     repr(obj)
 
 
+@log_entry_exit
 def test_datetime_str(datetime_init_tuple):
     """
     Test str(CIMDateTime) from all input types using
@@ -970,6 +1001,7 @@ TESTCASES_MINUTESFROMUTC_INIT = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_MINUTESFROMUTC_INIT)
 @simplified_test_function
+@log_entry_exit
 def test_MinutesFromUTC_init(testcase, args, kwargs, exp_offset):
     """
     Test function for MinutesFromUTC.__init__().
@@ -1023,24 +1055,14 @@ TESTCASES_MINUTESFROMUTC_UTCOFFSET = [
         None, None, True
     ),
     (
-        "Test with UTC offset 150 and datetime with tzinfo for EST (ignored)",
+        "Test with UTC offset 150 and datetime with tzinfo",
         dict(
             offset=150,
-            dt=datetime.now(pytz.timezone('US/Eastern')),
+            dt=datetime.now(tz=zoneinfo.ZoneInfo('US/Eastern')),
             exp_utc_offset=150,
         ),
         None, None, True
     ),
-    (
-        "Test with UTC offset -150 and datetime with tzinfo for EDT (ignored)",
-        dict(
-            offset=-150,
-            dt=pytz.timezone('US/Eastern').
-            localize(datetime.now(), is_dst=True),
-            exp_utc_offset=-150,
-        ),
-        None, None, True
-    ),
 ]
 
 
@@ -1048,6 +1070,7 @@ TESTCASES_MINUTESFROMUTC_UTCOFFSET = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_MINUTESFROMUTC_UTCOFFSET)
 @simplified_test_function
+@log_entry_exit
 def test_MinutesFromUTC_utcoffset(testcase, offset, dt, exp_utc_offset):
     """
     Test function for MinutesFromUTC.utcoffset().
@@ -1099,20 +1122,10 @@ TESTCASES_MINUTESFROMUTC_DST = [
         None, None, True
     ),
     (
-        "Test with UTC offset 150 and datetime with tzinfo for EST (ignored)",
+        "Test with UTC offset 150 and datetime with tzinfo",
         dict(
             offset=150,
-            dt=datetime.now(pytz.timezone('US/Eastern')),
-            exp_dst_offset=0,
-        ),
-        None, None, True
-    ),
-    (
-        "Test with UTC offset -150 and datetime with tzinfo for EDT (ignored)",
-        dict(
-            offset=-150,
-            dt=pytz.timezone('US/Eastern').
-            localize(datetime.now(), is_dst=True),
+            dt=datetime.now(tz=zoneinfo.ZoneInfo('US/Eastern')),
             exp_dst_offset=0,
         ),
         None, None, True
@@ -1124,6 +1137,7 @@ TESTCASES_MINUTESFROMUTC_DST = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_MINUTESFROMUTC_DST)
 @simplified_test_function
+@log_entry_exit
 def test_MinutesFromUTC_dst(testcase, offset, dt, exp_dst_offset):
     """
     Test function for MinutesFromUTC.dst().
@@ -1245,24 +1259,14 @@ TESTCASES_MINUTESFROMUTC_TZNAME = [
         None, None, True
     ),
     (
-        "Test with UTC offset 150 and datetime with tzinfo for EST (ignored)",
+        "Test with UTC offset 150 and datetime with tzinfo",
         dict(
             offset=150,
-            dt=datetime.now(pytz.timezone('US/Eastern')),
+            dt=datetime.now(tz=zoneinfo.ZoneInfo('US/Eastern')),
             exp_tzname='02:30',
         ),
         None, None, True
     ),
-    (
-        "Test with UTC offset -150 and datetime with tzinfo for EDT (ignored)",
-        dict(
-            offset=-150,
-            dt=pytz.timezone('US/Eastern').
-            localize(datetime.now(), is_dst=True),
-            exp_tzname='-02:30',
-        ),
-        None, None, True
-    ),
 ]
 
 
@@ -1270,6 +1274,7 @@ TESTCASES_MINUTESFROMUTC_TZNAME = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_MINUTESFROMUTC_TZNAME)
 @simplified_test_function
+@log_entry_exit
 def test_MinutesFromUTC_tzname(testcase, offset, dt, exp_tzname):
     """
     Test function for MinutesFromUTC.tzname().
@@ -1316,7 +1321,7 @@ TESTCASES_CIMTYPE = [
         "Object is a bool",
         dict(
             obj=True,
-            exp_type_name=u'boolean',
+            exp_type_name='boolean',
         ),
         None, None, True
     ),
@@ -1325,8 +1330,8 @@ TESTCASES_CIMTYPE = [
     (
         "Object is a unicode string",
         dict(
-            obj=u"abc",
-            exp_type_name=u'string',
+            obj="abc",
+            exp_type_name='string',
         ),
         None, None, True
     ),
@@ -1334,7 +1339,7 @@ TESTCASES_CIMTYPE = [
         "Object is a byte string",
         dict(
             obj=b"abc",
-            exp_type_name=u'string',
+            exp_type_name='string',
         ),
         None, None, True
     ),
@@ -1352,7 +1357,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Uint8 number",
         dict(
             obj=Uint8(42),
-            exp_type_name=u'uint8',
+            exp_type_name='uint8',
         ),
         None, None, True
     ),
@@ -1360,7 +1365,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Uint16 number",
         dict(
             obj=Uint16(42),
-            exp_type_name=u'uint16',
+            exp_type_name='uint16',
         ),
         None, None, True
     ),
@@ -1368,7 +1373,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Uint32 number",
         dict(
             obj=Uint32(42),
-            exp_type_name=u'uint32',
+            exp_type_name='uint32',
         ),
         None, None, True
     ),
@@ -1376,7 +1381,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Uint64 number",
         dict(
             obj=Uint64(42),
-            exp_type_name=u'uint64',
+            exp_type_name='uint64',
         ),
         None, None, True
     ),
@@ -1384,7 +1389,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Sint8 number",
         dict(
             obj=Sint8(42),
-            exp_type_name=u'sint8',
+            exp_type_name='sint8',
         ),
         None, None, True
     ),
@@ -1392,7 +1397,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Sint16 number",
         dict(
             obj=Sint16(42),
-            exp_type_name=u'sint16',
+            exp_type_name='sint16',
         ),
         None, None, True
     ),
@@ -1400,7 +1405,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Sint32 number",
         dict(
             obj=Sint32(42),
-            exp_type_name=u'sint32',
+            exp_type_name='sint32',
         ),
         None, None, True
     ),
@@ -1408,7 +1413,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Sint64 number",
         dict(
             obj=Sint64(42),
-            exp_type_name=u'sint64',
+            exp_type_name='sint64',
         ),
         None, None, True
     ),
@@ -1426,7 +1431,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Real32 number",
         dict(
             obj=Real32(42.0),
-            exp_type_name=u'real32',
+            exp_type_name='real32',
         ),
         None, None, True
     ),
@@ -1434,7 +1439,7 @@ TESTCASES_CIMTYPE = [
         "Object is a Real64 number",
         dict(
             obj=Real64(42.0),
-            exp_type_name=u'real64',
+            exp_type_name='real64',
         ),
         None, None, True
     ),
@@ -1446,7 +1451,7 @@ TESTCASES_CIMTYPE = [
             obj=datetime(year=2014, month=9, day=24, hour=19, minute=30,
                          second=40, microsecond=654321,
                          tzinfo=MinutesFromUTC(120)),
-            exp_type_name=u'datetime',
+            exp_type_name='datetime',
         ),
         None, None, True
     ),
@@ -1455,7 +1460,7 @@ TESTCASES_CIMTYPE = [
         dict(
             obj=timedelta(days=12345678, hours=22, minutes=44, seconds=55,
                           microseconds=654321),
-            exp_type_name=u'datetime',
+            exp_type_name='datetime',
         ),
         None, None, True
     ),
@@ -1463,7 +1468,7 @@ TESTCASES_CIMTYPE = [
         "Object is a CIMDateTime object",
         dict(
             obj=CIMDateTime('20140924193040.654321+000'),
-            exp_type_name=u'datetime',
+            exp_type_name='datetime',
         ),
         None, None, True
     ),
@@ -1473,7 +1478,7 @@ TESTCASES_CIMTYPE = [
         "Object is a CIMClass object",
         dict(
             obj=CIMClass('CIM_Foo'),
-            exp_type_name=u'string',  # embedded object
+            exp_type_name='string',  # embedded object
         ),
         None, None, True
     ),
@@ -1481,7 +1486,7 @@ TESTCASES_CIMTYPE = [
         "Object is a CIMInstance object",
         dict(
             obj=CIMInstance('CIM_Foo'),
-            exp_type_name=u'string',  # embedded object
+            exp_type_name='string',  # embedded object
         ),
         None, None, True
     ),
@@ -1489,7 +1494,7 @@ TESTCASES_CIMTYPE = [
         "Object is a CIMInstanceName object",
         dict(
             obj=CIMInstanceName('CIM_Foo'),
-            exp_type_name=u'reference',
+            exp_type_name='reference',
         ),
         None, None, True
     ),
@@ -1508,6 +1513,7 @@ TESTCASES_CIMTYPE = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_CIMTYPE)
 @simplified_test_function
+@log_entry_exit
 def test_cimtype(testcase, obj, exp_type_name):
     """
     Test function for cimtype().
@@ -1652,7 +1658,7 @@ TESTCASES_TYPE_FROM_NAME = [
         "Type name is string",
         dict(
             type_name='string',
-            exp_type_obj=six.text_type,
+            exp_type_obj=str,
         ),
         None, None, True
     ),
@@ -1660,7 +1666,7 @@ TESTCASES_TYPE_FROM_NAME = [
         "Type name is char16",
         dict(
             type_name='char16',
-            exp_type_obj=six.text_type,
+            exp_type_obj=str,
         ),
         None, None, True
     ),
@@ -1688,6 +1694,7 @@ TESTCASES_TYPE_FROM_NAME = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_TYPE_FROM_NAME)
 @simplified_test_function
+@log_entry_exit
 def test_type_from_name(testcase, type_name, exp_type_obj):
     """
     Test function for type_from_name().
