@@ -18,10 +18,7 @@
 Unit test logging functionality in _logging.py
 """
 
-from __future__ import absolute_import, print_function
-
 import os
-import io
 import re
 import logging
 
@@ -61,7 +58,7 @@ VERBOSE = False
 TEST_DIR = os.path.dirname(__file__)
 
 LOG_FILE_NAME = 'test_logging.log'
-TEST_OUTPUT_LOG = '%s/%s' % (TEST_DIR, LOG_FILE_NAME)
+TEST_OUTPUT_LOG = f'{TEST_DIR}/{LOG_FILE_NAME}'
 
 
 @pytest.fixture(autouse=True)
@@ -78,7 +75,7 @@ def log_capture():
         yield lc
 
 
-class TestLoggingConfigure(object):
+class TestLoggingConfigure:
     """Base class for logging unit tests"""
 
     @classmethod
@@ -106,7 +103,7 @@ class TestLoggingConfigure(object):
             elif log_name == 'http':
                 logger = logging.getLogger(LOGGER_HTTP_NAME)
             else:
-                assert 'Input error. log_name %s ' % log_name
+                assert f'Input error. log_name {log_name} '
 
             # TODO compare detail_level
 
@@ -425,7 +422,7 @@ def test_loggers_from_string(testcase, param, expected_result, log_file,
             os.remove(log_file)
 
 
-class BaseLoggingExecutionTests(object):
+class BaseLoggingExecutionTests:
     """Base class for logging execution tests"""
 
     def setup_method(self):
@@ -476,24 +473,24 @@ class TestLoggerOutput(BaseLoggingExecutionTests):
             raise AssertionError("ConnectionError exception not raised")
 
         exp_line_patterns = [
-            r".*-{0}\..*-Connection:.* WBEMConnection\(url='{1}'".
-            format(LOGGER_API_CALLS_NAME, url),
-            r".*-{0}\..*-Request:.* GetQualifier\(QualifierName='Association'".
-            format(LOGGER_API_CALLS_NAME),
-            r".*-{0}\..*-Request:.* POST /cimom .* CIMMethod:'GetQualifier'".
-            format(LOGGER_HTTP_NAME),
-            r".*-{0}\..*-Exception:.* GetQualifier.*ConnectionError".
-            format(LOGGER_API_CALLS_NAME),
+            fr".*-{LOGGER_API_CALLS_NAME}\..*-Connection:.* "
+            fr"WBEMConnection\(url='{url}'",
+            fr".*-{LOGGER_API_CALLS_NAME}\..*-Request:.* "
+            r"GetQualifier\(QualifierName='Association'",
+            fr".*-{LOGGER_HTTP_NAME}\..*-Request:.* "
+            r"POST /cimom .* CIMMethod:'GetQualifier'",
+            fr".*-{LOGGER_API_CALLS_NAME}\..*-Exception:.* "
+            "GetQualifier.*ConnectionError",
         ]
 
-        with io.open(TEST_OUTPUT_LOG, "r", encoding='utf-8') as log_fp:
+        with open(TEST_OUTPUT_LOG, encoding='utf-8') as log_fp:
             log_lines = log_fp.readlines()
         assert len(log_lines) == len(exp_line_patterns)
         for i, pattern in enumerate(exp_line_patterns):
             assert re.match(pattern, log_lines[i])
 
 
-class TestLoggerPropagate(object):
+class TestLoggerPropagate:
     # pylint: disable=too-few-public-methods
     """Test logging with propagate parameter variations"""
 
@@ -547,11 +544,11 @@ class TestLoggerPropagate(object):
 
         pkg_logger.removeHandler(pkg_handler)
 
-        with io.open(logger_filename, encoding='utf-8') as logger_fp:
+        with open(logger_filename, encoding='utf-8') as logger_fp:
             logger_line = logger_fp.read()
-        assert re.match(r'.*-%s\..*-Connection:' % logger_name, logger_line)
+        assert re.match(fr'.*-{logger_name}\..*-Connection:', logger_line)
 
-        with io.open(pkg_filename, encoding='utf-8') as pkg_fp:
+        with open(pkg_filename, encoding='utf-8') as pkg_fp:
             pkg_line = pkg_fp.read()
         if propagate:
             assert re.match(r'.*-pywbem.*-Connection:', pkg_line)
