@@ -4,22 +4,12 @@
 Measure performance of equality tests.
 """
 
-from __future__ import absolute_import
-
-import io
+import statistics
+from time import process_time, get_clock_info
 
 import pytest
-import six
-try:
-    import statistics
-except ImportError:
-    # Only on Python 2.7
-    from backports import statistics
-try:
-    from time import process_time, get_clock_info
-except ImportError:
-    # Only on Python 2.7
-    process_time = None
+
+from ..utils.pytest_extensions import log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from tests.utils import import_installed
@@ -95,6 +85,7 @@ TESTCASES_PERF_EQ = [
 @pytest.mark.parametrize(
     "desc, obj1, obj2",
     TESTCASES_PERF_EQ)
+@log_entry_exit
 def test_perf_eq(desc, obj1, obj2):
     """
     Measure performance of equality tests.
@@ -109,7 +100,7 @@ def test_perf_eq(desc, obj1, obj2):
 
     def measure():
         "One measurement"
-        for _ in six.moves.range(num):
+        for _ in range(num):
             # The code to be measured
             _ = (obj1 == obj2)
 
@@ -121,10 +112,9 @@ def test_perf_eq(desc, obj1, obj2):
 
     stdev_pct = 100.0 * stdev_us / t_us if t_us != 0 else 0.0
 
-    with io.open(outfile, 'a', encoding='utf-8') as fp:
-        fp.write("{}: {:.3f} us (std.dev. {:.1f}% in {} runs with {} "
-                 "outliers)\n".
-                 format(desc, t_us, stdev_pct, num_runs, num_out))
+    with open(outfile, 'a', encoding='utf-8') as fp:
+        fp.write(f"{desc}: {t_us:.3f} us (std.dev. {stdev_pct:.1f}% in "
+                 f"{num_runs} runs with {num_out} outliers)\n")
 
 
 def timeit(measure_func, precision):
@@ -149,9 +139,9 @@ def timeit(measure_func, precision):
 
     # Perform the measurement a number of times and store the results
     results = []
-    for _ in six.moves.range(num_runs):
+    for _ in range(num_runs):
         t1_s = process_time()
-        for _j in six.moves.range(rep):  # pylint: disable=unused-variable
+        for _j in range(rep):  # pylint: disable=unused-variable
             measure_func()
         t2_s = process_time()
         t_us = 1.0E6 * (t2_s - t1_s) / rep
