@@ -21,16 +21,16 @@
 """
 Test for the WBEMSubscriptionManager class.
 """
-from __future__ import absolute_import, print_function
 
 import os
 import re
+
 import pytest
 
 from ...utils import skip_if_moftab_regenerated
 from ..utils.dmtf_mof_schema_def import DMTF_TEST_SCHEMA_VER
 from ..utils.wbemserver_mock import WbemServerMock
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -115,7 +115,7 @@ SUBSCRIPTION_WBEM_SERVER_MOCK_DICT = {
 #       test_subscriptionmanager(...)) below. We will leave these functions
 #       because they do provide a broad set of test functionality in just a few
 #       tests (each tests creates the mock environment)
-class BaseMethodsForTests(object):
+class BaseMethodsForTests:
     """
     Base Class for tests contains all common methods and class level
     setup.
@@ -165,7 +165,7 @@ class BaseMethodsForTests(object):
         self.test_class = 'Test_IndicationProviderClass'
         self.test_class_namespace = 'test/TestProvider'
 
-        self.test_query = 'SELECT * from %s' % self.test_class
+        self.test_query = f'SELECT * from {self.test_class}'
         self.test_classname = CIMClassName(self.test_class,
                                            namespace=self.test_class_namespace)
 
@@ -291,8 +291,8 @@ class BaseMethodsForTests(object):
         if sum(counts) == 0:
             return True
 
-        print('ERROR: Server_id=%s. Unreleased filters=%s, subs=%s, dest=%s' %
-              (server_id, counts[0], counts[1], counts[2]))
+        print(f'ERROR: Server_id={server_id}. Unreleased filters={counts[0]}, '
+              f'subs={counts[1]}, dest={counts[2]}')
         return False
 
     def get_submgr_inst_counts(self, sub_mgr, server_id):
@@ -313,6 +313,7 @@ class BaseMethodsForTests(object):
 class TestSubMgrClass(BaseMethodsForTests):
     """Test of subscription manager"""
 
+    @log_entry_exit
     def test_create_owned_subscription(self):
         """
         Test Basic Creation of sub mgr, creation of owned subscription
@@ -321,7 +322,7 @@ class TestSubMgrClass(BaseMethodsForTests):
         sm = "test_create_delete_subscription"
         server = WBEMServer(self.conn)
 
-        listener_url = '%s:%s' % (self.conn.url, 50000)
+        listener_url = f'{self.conn.url}:{50000}'
 
         with WBEMSubscriptionManager(subscription_manager_id=sm) as sub_mgr:
 
@@ -403,6 +404,7 @@ class TestSubMgrClass(BaseMethodsForTests):
         # confirm no owned filters, destinations, subscriptions in server
         assert self.get_owned_inst_counts() == (0, 0, 0)
 
+    @log_entry_exit
     def test_create_permanent_subscription(self):
         """
         Test creating permanent filter, destination and filter and determining
@@ -412,7 +414,7 @@ class TestSubMgrClass(BaseMethodsForTests):
         sm = "test_create_delete_subscription"
         server = WBEMServer(self.conn)
 
-        listener_url = '%s:%s' % (self.conn.url, 50000)
+        listener_url = f'{self.conn.url}:{50000}'
         # Create a single not_owned subscription
         with WBEMSubscriptionManager(subscription_manager_id=sm) as sub_mgr:
             server_id = sub_mgr.add_server(server)
@@ -453,6 +455,7 @@ class TestSubMgrClass(BaseMethodsForTests):
                 sub_mgr.remove_filter(server_id, filter_.path)
             assert self.get_submgr_inst_counts(sub_mgr, server_id) == (0, 0, 0)
 
+    @log_entry_exit
     def test_recovery_of_owned_subscriptions(self):
         """
         Test the ability to recover owned subscriptions from the server. Tests
@@ -463,7 +466,7 @@ class TestSubMgrClass(BaseMethodsForTests):
         sm = "test_subscription_object_recovery"
         server = WBEMServer(self.conn)
 
-        listener_url = '%s:%s' % (self.conn.url, 50000)
+        listener_url = f'{self.conn.url}:{50000}'
 
         submgr1 = WBEMSubscriptionManager(subscription_manager_id=sm)
         server_id1 = submgr1.add_server(server)
@@ -1495,6 +1498,7 @@ TESTCASES_SUBMGR = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_SUBMGR)
 @simplified_test_function
+@log_entry_exit
 def test_subscriptionmanager(testcase, submgr_id, connection_attrs,
                              filter_attrs, dest_attrs, subscription_attrs,
                              remove_destinations, remove_filters,
@@ -1593,7 +1597,7 @@ def test_subscriptionmanager(testcase, submgr_id, connection_attrs,
         assert len(all_dests) == exp_result['listener_count']
 
         owned_dests = submgr.get_owned_destinations(server_id)
-        dest_prefix = 'pywbemdestination:{0}:'.format(submgr_id,)
+        dest_prefix = f'pywbemdestination:{submgr_id}:'
         owned = [d for d in all_dests if d['Name'].startswith(dest_prefix)]
         assert set(owned) == set(owned_dests)
 
@@ -1629,7 +1633,7 @@ def test_subscriptionmanager(testcase, submgr_id, connection_attrs,
                     assert created_instance[prop] == value
             else:
                 if created_instance[prop] != value:
-                    print("THEERROR\n{}".format(created_instance.tomof()))
+                    print(f"THEERROR\n{created_instance.tomof()}")
                 assert created_instance[prop] == value
 
     # The removal methods are executed after all others methods defined for
@@ -1885,6 +1889,7 @@ TESTCASES_SUBMGR_MODIFY = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_SUBMGR_MODIFY)
 @simplified_test_function
+@log_entry_exit
 def test_submgr_modify(testcase, submgr_id, connection_attrs,
                        filter_attrs, dest_attrs, subscription_attrs,
                        modify_filter_attrs, modify_dest_attrs,
@@ -2016,7 +2021,7 @@ def test_submgr_modify(testcase, submgr_id, connection_attrs,
 
         owned_dests = submgr.get_owned_destinations(server_id)
 
-        dest_prefix = 'pywbemdestination:{0}:'.format(submgr_id,)
+        dest_prefix = f'pywbemdestination:{submgr_id}:'
         owned = [d for d in all_dests if d['Name'].startswith(dest_prefix)]
         assert set(owned) == set(owned_dests)
 
