@@ -2,11 +2,9 @@
 Test functions in _units module
 """
 
-from __future__ import absolute_import
-
 import pytest
 
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -75,7 +73,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_PUNIT1_BYTE])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -87,7 +85,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', return_type='uint32',
                     qualifiers=[TEST_QUAL_PUNIT1_BYTE])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -99,7 +97,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', type='uint32',
                     qualifiers=[TEST_QUAL_PUNIT1_BYTE])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -111,7 +109,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_PUNIT2_BYTE])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -123,7 +121,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_UNITS1_BYTES])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -135,7 +133,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_UNITS2_BYTES])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -147,7 +145,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_PUNIT1_BYTE, TEST_QUAL_UNITS_METERS])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -159,7 +157,7 @@ TESTCASES_SIUNIT_OBJ = [
                     'P1', value='foo',
                     qualifiers=[TEST_QUAL_UNITS_METERS, TEST_QUAL_PUNIT1_BYTE])
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -170,6 +168,7 @@ TESTCASES_SIUNIT_OBJ = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_SIUNIT_OBJ)
 @simplified_test_function
+@log_entry_exit
 def test_siunit_obj(testcase, in_kwargs, exp_result):
     """
     Test function for siunit_obj().
@@ -212,7 +211,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="",
             ),
-            exp_result=u'',
+            exp_result='',
         ),
         None, None, True
     ),
@@ -220,9 +219,9 @@ TESTCASES_SIUNIT_GENERAL = [
         "PUnit 'byte' as Unicode string",
         dict(
             in_kwargs=dict(
-                punit=u"byte",
+                punit="byte",
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -232,7 +231,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit=b"byte",
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -240,9 +239,9 @@ TESTCASES_SIUNIT_GENERAL = [
         "Units 'Bytes' as Unicode string",
         dict(
             in_kwargs=dict(
-                units=u"Bytes",
+                units="Bytes",
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -252,7 +251,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 units=b"Bytes",
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -263,7 +262,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="byte",
                 units="Meters",
             ),
-            exp_result=u'B',
+            exp_result='B',
         ),
         None, None, True
     ),
@@ -273,7 +272,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="degree",
             ),
-            exp_result=u'\u00B0',
+            exp_result='\u00B0',
         ),
         None, None, True
     ),
@@ -284,7 +283,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="degree",
                 use_ascii=False,
             ),
-            exp_result=u'\u00B0',
+            exp_result='\u00B0',
         ),
         None, None, True
     ),
@@ -295,7 +294,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="degree",
                 use_ascii=True,
             ),
-            exp_result=u'deg',
+            exp_result='deg',
         ),
         None, None, True
     ),
@@ -306,7 +305,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="degree celsius",
                 use_ascii=True,
             ),
-            exp_result=u'degC',
+            exp_result='degC',
         ),
         None, None, True
     ),
@@ -317,7 +316,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="degree fahrenheit",
                 use_ascii=True,
             ),
-            exp_result=u'degF',
+            exp_result='degF',
         ),
         None, None, True
     ),
@@ -328,7 +327,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="ohm",
                 use_ascii=True,
             ),
-            exp_result=u'Ohm',
+            exp_result='Ohm',
         ),
         None, None, True
     ),
@@ -339,7 +338,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="permille",
                 use_ascii=True,
             ),
-            exp_result=u'1/1000',
+            exp_result='1/1000',
         ),
         None, None, True
     ),
@@ -350,7 +349,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="meter * meter",
                 use_ascii=True,
             ),
-            exp_result=u'm^2',
+            exp_result='m^2',
         ),
         None, None, True
     ),
@@ -361,7 +360,7 @@ TESTCASES_SIUNIT_GENERAL = [
                 punit="meter * meter * meter",
                 use_ascii=True,
             ),
-            exp_result=u'm^3',
+            exp_result='m^3',
         ),
         None, None, True
     ),
@@ -411,7 +410,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 10000",
             ),
-            exp_result=u'10000 s',
+            exp_result='10000 s',
         ),
         None, None, True
     ),
@@ -421,7 +420,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 10000",
             ),
-            exp_result=u'1/10000 s',
+            exp_result='1/10000 s',
         ),
         None, None, True
     ),
@@ -431,7 +430,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 10 ^ 4",
             ),
-            exp_result=u'10^4 s',
+            exp_result='10^4 s',
         ),
         None, None, True
     ),
@@ -441,7 +440,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 10 ^ 4",
             ),
-            exp_result=u'10^-4 s',
+            exp_result='10^-4 s',
         ),
         None, None, True
     ),
@@ -451,7 +450,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 10 * 10 ^ 3",
             ),
-            exp_result=u'10 ks',
+            exp_result='10 ks',
         ),
         None, None, True
     ),
@@ -461,7 +460,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 10 / 10 ^ 3",
             ),
-            exp_result=u'1/10 ms',
+            exp_result='1/10 ms',
         ),
         None, None, True
     ),
@@ -471,7 +470,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 10 * 10 ^ -3",
             ),
-            exp_result=u'10 ms',
+            exp_result='10 ms',
         ),
         None, None, True
     ),
@@ -481,7 +480,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 10 / 10 ^ -3",
             ),
-            exp_result=u'1/10 ks',
+            exp_result='1/10 ks',
         ),
         None, None, True
     ),
@@ -491,7 +490,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 1000 * 10 ^ 4",
             ),
-            exp_result=u'1000 10^4 s',
+            exp_result='1000 10^4 s',
         ),
         None, None, True
     ),
@@ -501,7 +500,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 1000 / 10 ^ 4",
             ),
-            exp_result=u'1/1000 10^-4 s',
+            exp_result='1/1000 10^-4 s',
         ),
         None, None, True
     ),
@@ -511,7 +510,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second * 10000 * 10 ^ 3",
             ),
-            exp_result=u'10000 ks',
+            exp_result='10000 ks',
         ),
         None, None, True
     ),
@@ -521,7 +520,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="second / 10000 / 10 ^ 3",
             ),
-            exp_result=u'1/10000 ms',
+            exp_result='1/10000 ms',
         ),
         None, None, True
     ),
@@ -531,7 +530,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="meter * 1000 / second",
             ),
-            exp_result=u'km/s',
+            exp_result='km/s',
         ),
         None, None, True
     ),
@@ -541,7 +540,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="watt / 10^3 * second",
             ),
-            exp_result=u'mWs',
+            exp_result='mWs',
         ),
         None, None, True
     ),
@@ -551,7 +550,7 @@ TESTCASES_SIUNIT_GENERAL = [
             in_kwargs=dict(
                 punit="meter / 10 * 10^3 / second",
             ),
-            exp_result=u'1/10 km/s',
+            exp_result='1/10 km/s',
         ),
         None, None, True
     ),
@@ -592,6 +591,7 @@ TESTCASES_SIUNIT_GENERAL = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_SIUNIT_GENERAL)
 @simplified_test_function
+@log_entry_exit
 def test_siunit_general(testcase, in_kwargs, exp_result):
     """
     Test function for siunit(), that test general behavior.
@@ -616,144 +616,145 @@ TESTCASES_SIUNIT_PUNIT = [
     # * exp_result: Expected return value of siunit().
 
     # All single units
-    ("percent", u"%"),
-    ("permille", u"\u2030"),
-    ("decibel", u"dB"),
-    ("count", u""),
-    ("revolution", u"rev"),
-    ("degree", u"\u00B0"),
-    ("radian", u"rad"),
-    ("steradian", u"sr"),
-    ("bit", u"bit"),
-    ("byte", u"B"),
-    ("dataword", u"word"),
-    ("MSU", u"MSU"),
-    ("meter", u"m"),
-    ("inch", u"in"),
-    ("rack unit", u"U"),
-    ("foot", u"ft"),
-    ("yard", u"yd"),
-    ("mile", u"mi"),
-    ("liter", u"l"),
-    ("fluid ounce", u"fl.oz"),
-    ("liquid gallon", u"gal"),
-    ("mole", u"mol"),
-    ("kilogram", u"kg"),
-    ("ounce", u"oz"),
-    ("pound", u"lb"),
-    ("second", u"s"),
-    ("minute", u"min"),
-    ("hour", u"h"),
-    ("day", u"d"),
-    ("week", u"week"),
-    ("gravity", u"g"),
-    ("degree celsius", u"\u00B0C"),
-    ("degree fahrenheit", u"\u00B0F"),
-    ("kelvin", u"K"),
-    ("candela", u"cd"),
-    ("lumen", u"lm"),
-    ("nit", u"nit"),
-    ("lux", u"lx"),
-    ("newton", u"N"),
-    ("pascal", u"Pa"),
-    ("bar", u"bar"),
-    ("decibel(A)", u"dB(A)"),
-    ("decibel (A)", u"dB(A)"),
-    ("decibel(C)", u"dB(C)"),
-    ("decibel (C)", u"dB(C)"),
-    ("joule", u"J"),
-    ("watt", u"W"),
-    ("volt ampere", u"VA"),
-    ("volt ampere reactive", u"var"),
-    ("decibel(m)", u"dBm"),
-    ("decibel (m)", u"dBm"),
-    ("british thermal unit", u"BTU"),
-    ("ampere", u"A"),
-    ("coulomb", u"C"),
-    ("volt", u"V"),
-    ("farad", u"F"),
-    ("ohm", u"\u2126"),
-    ("siemens", u"S"),
-    ("weber", u"Wb"),
-    ("tesla", u"T"),
-    ("henry", u"H"),
-    ("becquerel", u"Bq"),
-    ("gray", u"Gy"),
-    ("sievert", u"Sv"),
+    ("percent", "%"),
+    ("permille", "\u2030"),
+    ("decibel", "dB"),
+    ("count", ""),
+    ("revolution", "rev"),
+    ("degree", "\u00B0"),
+    ("radian", "rad"),
+    ("steradian", "sr"),
+    ("bit", "bit"),
+    ("byte", "B"),
+    ("dataword", "word"),
+    ("MSU", "MSU"),
+    ("meter", "m"),
+    ("inch", "in"),
+    ("rack unit", "U"),
+    ("foot", "ft"),
+    ("yard", "yd"),
+    ("mile", "mi"),
+    ("liter", "l"),
+    ("fluid ounce", "fl.oz"),
+    ("liquid gallon", "gal"),
+    ("mole", "mol"),
+    ("kilogram", "kg"),
+    ("ounce", "oz"),
+    ("pound", "lb"),
+    ("second", "s"),
+    ("minute", "min"),
+    ("hour", "h"),
+    ("day", "d"),
+    ("week", "week"),
+    ("gravity", "g"),
+    ("degree celsius", "\u00B0C"),
+    ("degree fahrenheit", "\u00B0F"),
+    ("kelvin", "K"),
+    ("candela", "cd"),
+    ("lumen", "lm"),
+    ("nit", "nit"),
+    ("lux", "lx"),
+    ("newton", "N"),
+    ("pascal", "Pa"),
+    ("bar", "bar"),
+    ("decibel(A)", "dB(A)"),
+    ("decibel (A)", "dB(A)"),
+    ("decibel(C)", "dB(C)"),
+    ("decibel (C)", "dB(C)"),
+    ("joule", "J"),
+    ("watt", "W"),
+    ("volt ampere", "VA"),
+    ("volt ampere reactive", "var"),
+    ("decibel(m)", "dBm"),
+    ("decibel (m)", "dBm"),
+    ("british thermal unit", "BTU"),
+    ("ampere", "A"),
+    ("coulomb", "C"),
+    ("volt", "V"),
+    ("farad", "F"),
+    ("ohm", "\u2126"),
+    ("siemens", "S"),
+    ("weber", "Wb"),
+    ("tesla", "T"),
+    ("henry", "H"),
+    ("becquerel", "Bq"),
+    ("gray", "Gy"),
+    ("sievert", "Sv"),
 
     # Multiple same units combined (using powers), without modifiers
-    ("meter*meter", u"m\u00B2"),
-    ("meter * meter", u"m\u00B2"),
-    ("meter * meter * meter", u"m\u00B3"),
-    ("meter * meter * meter * meter", u"m^4"),
-    ("meter / second / second", u"m/s\u00B2"),
-    ("meter * meter / second / second / second", u"m\u00B2/s\u00B3"),
+    ("meter*meter", "m\u00B2"),
+    ("meter * meter", "m\u00B2"),
+    ("meter * meter * meter", "m\u00B3"),
+    ("meter * meter * meter * meter", "m^4"),
+    ("meter / second / second", "m/s\u00B2"),
+    ("meter * meter / second / second / second", "m\u00B2/s\u00B3"),
     ("meter * meter * meter / second / second / second / second",
-     u"m\u00B3/s^4"),
+     "m\u00B3/s^4"),
 
     # Multiple units combined, without powers, without modifiers
-    ("meter/second", u"m/s"),
-    ("meter / second", u"m/s"),
-    ("newton * meter", u"Nm"),
-    ("newton * meter / second", u"Nm/s"),
-    ("newton * meter / second / byte", u"Nm/sB"),
-    ("meter * newton / byte / second", u"mN/Bs"),
+    ("meter/second", "m/s"),
+    ("meter / second", "m/s"),
+    ("newton * meter", "Nm"),
+    ("newton * meter / second", "Nm/s"),
+    ("newton * meter / second / byte", "Nm/sB"),
+    ("meter * newton / byte / second", "mN/Bs"),
 
     # Using modifier1
-    ("byte*1024", u"KiB"),
-    ("byte * 1024", u"KiB"),
-    ("meter / second * 1000", u"km/s"),
-    ("meter / second * 100", u"hm/s"),
-    ("meter / second * 10", u"dam/s"),
-    ("meter / second * 1", u"m/s"),
-    ("meter / second / 1", u"m/s"),
-    ("meter / second / 10", u"dm/s"),
-    ("meter / second / 100", u"cm/s"),
-    ("meter / second / 1000", u"mm/s"),
+    ("byte*1024", "KiB"),
+    ("byte * 1024", "KiB"),
+    ("meter / second * 1000", "km/s"),
+    ("meter / second * 100", "hm/s"),
+    ("meter / second * 10", "dam/s"),
+    ("meter / second * 1", "m/s"),
+    ("meter / second / 1", "m/s"),
+    ("meter / second / 10", "dm/s"),
+    ("meter / second / 100", "cm/s"),
+    ("meter / second / 1000", "mm/s"),
 
     # Using modifier2
-    ("byte*10^3", u"kB"),
-    ("byte * 10^3", u"kB"),
-    ("byte * 10 ^ 3", u"kB"),
-    ("byte * 2 ^ 80", u"YiB"),
-    ("byte * 2 ^ 70", u"ZiB"),
-    ("byte * 2 ^ 60", u"EiB"),
-    ("byte * 2 ^ 50", u"PiB"),
-    ("byte * 2 ^ 40", u"TiB"),
-    ("byte * 2 ^ 30", u"GiB"),
-    ("byte * 2 ^ 20", u"MiB"),
-    ("byte * 2 ^ 10", u"KiB"),
-    ("byte * 10 ^ 24", u"YB"),
-    ("byte * 10 ^ 21", u"ZB"),
-    ("byte * 10 ^ 18", u"EB"),
-    ("byte * 10 ^ 15", u"PB"),
-    ("byte * 10 ^ 12", u"TB"),
-    ("byte * 10 ^ 9", u"GB"),
-    ("byte * 10 ^ 6", u"MB"),
-    ("byte * 10 ^ 3", u"kB"),
-    ("byte * 10 ^ 2", u"hB"),
-    ("byte * 10 ^ 1", u"daB"),
-    ("byte * 10 ^ -1", u"dB"),
-    ("byte * 10 ^ -2", u"cB"),
-    ("byte * 10 ^ -3", u"mB"),
-    ("byte * 10 ^ -6", u"uB"),
-    ("byte * 10 ^ -9", u"nB"),
-    ("byte * 10 ^ -12", u"pB"),
-    ("byte * 10 ^ -15", u"fB"),
-    ("byte * 10 ^ -18", u"aB"),
-    ("byte * 10 ^ -21", u"zB"),
-    ("byte * 10 ^ -24", u"yB"),
+    ("byte*10^3", "kB"),
+    ("byte * 10^3", "kB"),
+    ("byte * 10 ^ 3", "kB"),
+    ("byte * 2 ^ 80", "YiB"),
+    ("byte * 2 ^ 70", "ZiB"),
+    ("byte * 2 ^ 60", "EiB"),
+    ("byte * 2 ^ 50", "PiB"),
+    ("byte * 2 ^ 40", "TiB"),
+    ("byte * 2 ^ 30", "GiB"),
+    ("byte * 2 ^ 20", "MiB"),
+    ("byte * 2 ^ 10", "KiB"),
+    ("byte * 10 ^ 24", "YB"),
+    ("byte * 10 ^ 21", "ZB"),
+    ("byte * 10 ^ 18", "EB"),
+    ("byte * 10 ^ 15", "PB"),
+    ("byte * 10 ^ 12", "TB"),
+    ("byte * 10 ^ 9", "GB"),
+    ("byte * 10 ^ 6", "MB"),
+    ("byte * 10 ^ 3", "kB"),
+    ("byte * 10 ^ 2", "hB"),
+    ("byte * 10 ^ 1", "daB"),
+    ("byte * 10 ^ -1", "dB"),
+    ("byte * 10 ^ -2", "cB"),
+    ("byte * 10 ^ -3", "mB"),
+    ("byte * 10 ^ -6", "uB"),
+    ("byte * 10 ^ -9", "nB"),
+    ("byte * 10 ^ -12", "pB"),
+    ("byte * 10 ^ -15", "fB"),
+    ("byte * 10 ^ -18", "aB"),
+    ("byte * 10 ^ -21", "zB"),
+    ("byte * 10 ^ -24", "yB"),
 
     # Using modifier1 and modifier2
-    ("byte*2*10^3", u"2 kB"),
-    ("byte * 2 * 10 ^ 3", u"2 kB"),
-    ("byte * 10 * 10 ^ 3", u"10 kB"),
+    ("byte*2*10^3", "2 kB"),
+    ("byte * 2 * 10 ^ 3", "2 kB"),
+    ("byte * 10 * 10 ^ 3", "10 kB"),
 ]
 
 
 @pytest.mark.parametrize(
     "punit, exp_result",
     TESTCASES_SIUNIT_PUNIT)
+@log_entry_exit
 def test_siunit_punit(punit, exp_result):
     """
     Test function for siunit(), that test only good cases with PUnit values.
@@ -775,167 +776,168 @@ TESTCASES_SIUNIT_UNITS = [
 
     # All units defined in DSP0004
 
-    ("Bits", u"bit"),
-    ("KiloBits", u"kbit"),
-    ("MegaBits", u"Mbit"),
-    ("GigaBits", u"Gbit"),
+    ("Bits", "bit"),
+    ("KiloBits", "kbit"),
+    ("MegaBits", "Mbit"),
+    ("GigaBits", "Gbit"),
 
-    ("Bits per Second", u"bit/s"),
-    ("KiloBits per Second", u"kbit/s"),
-    ("MegaBits per Second", u"Mbit/s"),
-    ("GigaBits per Second", u"Gbit/s"),
+    ("Bits per Second", "bit/s"),
+    ("KiloBits per Second", "kbit/s"),
+    ("MegaBits per Second", "Mbit/s"),
+    ("GigaBits per Second", "Gbit/s"),
 
-    ("Bytes", u"B"),
-    ("KiloBytes", u"kB"),
-    ("MegaBytes", u"MB"),
-    ("GigaBytes", u"GB"),
-    ("Words", u"words"),
-    ("DoubleWords", u"doublewords"),
-    ("QuadWords", u"quadwords"),
+    ("Bytes", "B"),
+    ("KiloBytes", "kB"),
+    ("MegaBytes", "MB"),
+    ("GigaBytes", "GB"),
+    ("Words", "words"),
+    ("DoubleWords", "doublewords"),
+    ("QuadWords", "quadwords"),
 
-    ("Degrees C", u"\u00B0C"),
-    ("Tenths of Degrees C", u"1/10 \u00B0C"),
-    ("Hundredths of Degrees C", u"1/100 \u00B0C"),
-    ("Degrees F", u"\u00B0F"),
-    ("Tenths of Degrees F", u"1/10 \u00B0F"),
-    ("Hundredths of Degrees F", u"1/100 \u00B0F"),
-    ("Degrees K", u"K"),
-    ("Tenths of Degrees K", u"1/10 K"),
-    ("Hundredths of Degrees K", u"1/100 K"),
-    ("Color Temperature", u"K"),
+    ("Degrees C", "\u00B0C"),
+    ("Tenths of Degrees C", "1/10 \u00B0C"),
+    ("Hundredths of Degrees C", "1/100 \u00B0C"),
+    ("Degrees F", "\u00B0F"),
+    ("Tenths of Degrees F", "1/10 \u00B0F"),
+    ("Hundredths of Degrees F", "1/100 \u00B0F"),
+    ("Degrees K", "K"),
+    ("Tenths of Degrees K", "1/10 K"),
+    ("Hundredths of Degrees K", "1/100 K"),
+    ("Color Temperature", "K"),
 
-    ("Volts", u"V"),
-    ("MilliVolts", u"mV"),
-    ("Tenths of MilliVolts", u"1/10 mV"),
-    ("Amps", u"A"),
-    ("MilliAmps", u"mA"),
-    ("Tenths of MilliAmps", u"1/10 mA"),
-    ("Watts", u"W"),
-    ("MilliWattHours", u"mWh"),
+    ("Volts", "V"),
+    ("MilliVolts", "mV"),
+    ("Tenths of MilliVolts", "1/10 mV"),
+    ("Amps", "A"),
+    ("MilliAmps", "mA"),
+    ("Tenths of MilliAmps", "1/10 mA"),
+    ("Watts", "W"),
+    ("MilliWattHours", "mWh"),
 
-    ("Joules", u"J"),
-    ("Coulombs", u"C"),
-    ("Newtons", u"N"),
+    ("Joules", "J"),
+    ("Coulombs", "C"),
+    ("Newtons", "N"),
 
-    ("Lumen", u"lm"),
-    ("Lux", u"lx"),
-    ("Candelas", u"cd"),
+    ("Lumen", "lm"),
+    ("Lux", "lx"),
+    ("Candelas", "cd"),
 
-    ("Pounds", u"lb"),
-    ("Pounds per Square Inch", u"lb/in\u00B2"),
+    ("Pounds", "lb"),
+    ("Pounds per Square Inch", "lb/in\u00B2"),
 
-    ("Cycles", u"cycles"),
-    ("Revolutions", u"rev"),
-    ("Revolutions per Minute", u"RPM"),
-    ("Revolutions per Second", u"rev/s"),
+    ("Cycles", "cycles"),
+    ("Revolutions", "rev"),
+    ("Revolutions per Minute", "RPM"),
+    ("Revolutions per Second", "rev/s"),
 
-    ("Minutes", u"min"),
-    ("Seconds", u"s"),
-    ("Tenths of Seconds", u"1/10 s"),
-    ("Hundredths of Seconds", u"1/100 s"),
-    ("MicroSeconds", u"\u00B5s"),
-    ("MilliSeconds", u"ms"),
-    ("NanoSeconds", u"ns"),
+    ("Minutes", "min"),
+    ("Seconds", "s"),
+    ("Tenths of Seconds", "1/10 s"),
+    ("Hundredths of Seconds", "1/100 s"),
+    ("MicroSeconds", "\u00B5s"),
+    ("MilliSeconds", "ms"),
+    ("NanoSeconds", "ns"),
 
-    ("Hours", u"h"),
-    ("Days", u"d"),
-    ("Weeks", u"week"),
+    ("Hours", "h"),
+    ("Days", "d"),
+    ("Weeks", "week"),
 
-    ("Hertz", u"Hz"),
-    ("MegaHertz", u"MHz"),
+    ("Hertz", "Hz"),
+    ("MegaHertz", "MHz"),
 
-    ("Pixels", u"px"),
-    ("Pixels per Inch", u"px/in"),
+    ("Pixels", "px"),
+    ("Pixels per Inch", "px/in"),
 
-    ("Counts per Inch", u"counts/in"),
+    ("Counts per Inch", "counts/in"),
 
-    ("Percent", u"%"),
-    ("Tenths of Percent", u"1/10 %"),
-    ("Hundredths of Percent", u"1/100 %"),
-    ("Thousandths", u"\u2030"),
+    ("Percent", "%"),
+    ("Tenths of Percent", "1/10 %"),
+    ("Hundredths of Percent", "1/100 %"),
+    ("Thousandths", "\u2030"),
 
-    ("Meters", u"m"),
-    ("Centimeters", u"cm"),
-    ("Millimeters", u"mm"),
-    ("Cubic Meters", u"m\u00B3"),
-    ("Cubic Centimeters", u"cm\u00B3"),
-    ("Cubic Millimeters", u"mm\u00B3"),
+    ("Meters", "m"),
+    ("Centimeters", "cm"),
+    ("Millimeters", "mm"),
+    ("Cubic Meters", "m\u00B3"),
+    ("Cubic Centimeters", "cm\u00B3"),
+    ("Cubic Millimeters", "mm\u00B3"),
 
-    ("Inches", u"in"),
-    ("Feet", u"ft"),
-    ("Cubic Inches", u"in\u00B3"),
-    ("Cubic Feet", u"ft\u00B3"),
-    ("Ounces", u"oz"),
-    ("Liters", u"l"),
-    ("Fluid Ounces", u"fl.oz"),
+    ("Inches", "in"),
+    ("Feet", "ft"),
+    ("Cubic Inches", "in\u00B3"),
+    ("Cubic Feet", "ft\u00B3"),
+    ("Ounces", "oz"),
+    ("Liters", "l"),
+    ("Fluid Ounces", "fl.oz"),
 
-    ("Radians", u"rad"),
-    ("Steradians", u"sr"),
-    ("Degrees", u"\u00B0"),
+    ("Radians", "rad"),
+    ("Steradians", "sr"),
+    ("Degrees", "\u00B0"),
 
-    ("Gravities", u"g"),
-    ("Pounds", u"lb"),
-    ("Foot-Pounds", u"ft.lb"),
+    ("Gravities", "g"),
+    ("Pounds", "lb"),
+    ("Foot-Pounds", "ft.lb"),
 
-    ("Gauss", u"G"),
-    ("Gilberts", u"Gb"),
-    ("Henrys", u"H"),
-    ("MilliHenrys", u"mH"),
-    ("Farads", u"F"),
-    ("MilliFarads", u"mF"),
-    ("MicroFarads", u"\u00B5F"),
-    ("PicoFarads", u"pF"),
+    ("Gauss", "G"),
+    ("Gilberts", "Gb"),
+    ("Henrys", "H"),
+    ("MilliHenrys", "mH"),
+    ("Farads", "F"),
+    ("MilliFarads", "mF"),
+    ("MicroFarads", "\u00B5F"),
+    ("PicoFarads", "pF"),
 
-    ("Ohms", u"\u2126"),
-    ("Siemens", u"S"),
+    ("Ohms", "\u2126"),
+    ("Siemens", "S"),
 
-    ("Moles", u"mol"),
-    ("Becquerels", u"Bq"),
-    ("Parts per Million", u"ppm"),
+    ("Moles", "mol"),
+    ("Becquerels", "Bq"),
+    ("Parts per Million", "ppm"),
 
-    ("Decibels", u"dB"),
-    ("Tenths of Decibels", u"1/10 dB"),
+    ("Decibels", "dB"),
+    ("Tenths of Decibels", "1/10 dB"),
 
-    ("Grays", u"Gy"),
-    ("Sieverts", u"Sv"),
+    ("Grays", "Gy"),
+    ("Sieverts", "Sv"),
 
-    ("MilliWatts", u"mW"),
+    ("MilliWatts", "mW"),
 
-    ("DBm", u"dBm"),
+    ("DBm", "dBm"),
 
-    ("Bytes per Second", u"B/s"),
-    ("KiloBytes per Second", u"kB/s"),
-    ("MegaBytes per Second", u"MB/s"),
-    ("GigaBytes per Second", u"GB/s"),
+    ("Bytes per Second", "B/s"),
+    ("KiloBytes per Second", "kB/s"),
+    ("MegaBytes per Second", "MB/s"),
+    ("GigaBytes per Second", "GB/s"),
 
-    ("BTU per Hour", u"BTU/h"),
+    ("BTU per Hour", "BTU/h"),
 
-    ("PCI clock cycles", u"PCI clock cycles"),
+    ("PCI clock cycles", "PCI clock cycles"),
 
-    ("250 NanoSeconds", u"250 ns"),
+    ("250 NanoSeconds", "250 ns"),
 
-    ("Us", u"U"),
+    ("Us", "U"),
 
-    ("Amps at 120 Volts", u"A (@120V)"),
+    ("Amps at 120 Volts", "A (@120V)"),
 
-    ("Clock Ticks", u"clock ticks"),
+    ("Clock Ticks", "clock ticks"),
 
-    ("Packets", u"packets"),
-    ("per Thousand Packets", u"/1000 packets"),
+    ("Packets", "packets"),
+    ("per Thousand Packets", "/1000 packets"),
 
     # Additional values found in the DMTF CIM Schema (as of its version 2.49)
     # that are not defined as valid values in Annex C.2 of DSP0004 version 2.8
-    ("-dBm", u"-dBm"),
-    ("Blocks", u"blocks"),
-    ("Percentage", u"%"),
-    ("Proportion", u"proportion"),
-    ("Tenths of Revolutions per Minute", u"1/10 RPM"),
+    ("-dBm", "-dBm"),
+    ("Blocks", "blocks"),
+    ("Percentage", "%"),
+    ("Proportion", "proportion"),
+    ("Tenths of Revolutions per Minute", "1/10 RPM"),
 ]
 
 
 @pytest.mark.parametrize(
     "units, exp_result",
     TESTCASES_SIUNIT_UNITS)
+@log_entry_exit
 def test_siunit_units(units, exp_result):
     """
     Test function for siunit(), that test only good cases with Units values.
