@@ -3,15 +3,12 @@
     Test ValueMapping class
 """
 
-from __future__ import absolute_import
-
 import re
+from unittest.mock import Mock
+
 import pytest
 
-try:
-    from unittest.mock import Mock
-except ImportError:
-    from mock import Mock
+from ..utils.pytest_extensions import log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -73,7 +70,7 @@ def server_arg(request):
     return request.param
 
 
-class Test_ValueMapping(object):
+class Test_ValueMapping:
     """
     All tests for ValueMapping class.
     """
@@ -165,7 +162,7 @@ class Test_ValueMapping(object):
         values qualifiers.
         """
         server = getattr(self, server_arg)
-        setup_func_name = 'setup_for_%s' % element_kind
+        setup_func_name = f'setup_for_{element_kind}'
         setup_func = getattr(self, setup_func_name)
 
         vm = setup_func(server, integer_type, is_array, valuemap, values,
@@ -197,6 +194,7 @@ class Test_ValueMapping(object):
         assert re.match(".*outside of the set defined by its Values "
                         "qualifier.*", exc_msg) is not None
 
+    @log_entry_exit
     def test_empty(self, element_kind, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test empty ValueMapping"""
@@ -209,6 +207,7 @@ class Test_ValueMapping(object):
         self.assertOutsideValueMap(vm, 0)
         self.assertOutsideValues(vm, 'x')
 
+    @log_entry_exit
     def test_attrs_property(self, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test attributes of ValueMapping for a CIM property"""
@@ -231,6 +230,7 @@ class Test_ValueMapping(object):
         assert prop.name == PROPNAME
         assert prop.type == integer_type
 
+    @log_entry_exit
     def test_attrs_method(self, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test attributes of ValueMapping for a CIM method"""
@@ -253,6 +253,7 @@ class Test_ValueMapping(object):
         assert meth.name == METHNAME
         assert meth.return_type == integer_type
 
+    @log_entry_exit
     def test_attrs_parameter(self, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test attributes of ValueMapping for a CIM parameter"""
@@ -275,6 +276,7 @@ class Test_ValueMapping(object):
         assert parm.name == PARMNAME
         assert parm.type == integer_type
 
+    @log_entry_exit
     def test_repr(self, element_kind, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test ValueMapping.__repr__()"""
@@ -290,29 +292,30 @@ class Test_ValueMapping(object):
 
         # pylint: disable=protected-access
 
-        exp_conn = '_conn=%r' % vm._conn
+        exp_conn = f'_conn={vm._conn!r}'
         assert exp_conn in r
 
-        exp_namespace = '_namespace=%r' % vm._namespace
+        exp_namespace = f'_namespace={vm._namespace!r}'
         assert exp_namespace in r
 
-        exp_classname = '_classname=%r' % vm._classname
+        exp_classname = f'_classname={vm._classname!r}'
         assert exp_classname in r
 
-        exp_propname = '_propname=%r' % vm._propname
+        exp_propname = f'_propname={vm._propname!r}'
         assert exp_propname in r
 
-        exp_methodname = '_methodname=%r' % vm._methodname
+        exp_methodname = f'_methodname={vm._methodname!r}'
         assert exp_methodname in r
 
-        exp_parametername = '_parametername=%r' % vm._parametername
+        exp_parametername = f'_parametername={vm._parametername!r}'
         assert exp_parametername in r
 
-        exp_element_obj = '_element_obj=%r' % vm._element_obj
+        exp_element_obj = f'_element_obj={vm._element_obj!r}'
         assert exp_element_obj in r
 
         # We don't check the internal data attributes.
 
+    @log_entry_exit
     def test_invalid_valuemap_format(self, element_kind, server_arg,
                                      integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -330,6 +333,7 @@ class Test_ValueMapping(object):
                         "ValueMap entry.*",
                         exc_msg) is not None
 
+    @log_entry_exit
     def test_invalid_element_type(self, element_kind, server_arg, is_array):
         # pylint: disable=redefined-outer-name
         """Test invalid type for the element"""
@@ -345,6 +349,7 @@ class Test_ValueMapping(object):
         assert re.match(".*is not integer-typed.*",
                         exc_msg) is not None
 
+    @log_entry_exit
     def test_invalid_tovalues_type(self, element_kind, server_arg,
                                    integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -363,6 +368,7 @@ class Test_ValueMapping(object):
         assert re.match(".*is not integer-typed.*",
                         exc_msg) is not None
 
+    @log_entry_exit
     def test_invalid_tobinary_type(self, element_kind, server_arg,
                                    integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -381,6 +387,7 @@ class Test_ValueMapping(object):
         assert re.match(".*is not string-typed.*",
                         exc_msg) is not None
 
+    @log_entry_exit
     def test_no_values_qualifier(self, element_kind, server_arg, integer_type,
                                  is_array):
         # pylint: disable=redefined-outer-name
@@ -397,6 +404,7 @@ class Test_ValueMapping(object):
         assert re.match(".*has no Values qualifier defined.*",
                         exc_msg) is not None
 
+    @log_entry_exit
     def test_valuemap_default(self, element_kind, server_arg, integer_type,
                               is_array):
         # pylint: disable=redefined-outer-name
@@ -425,6 +433,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_zero(self, element_kind, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test valuemap with value 0"""
@@ -447,6 +456,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_one(self, element_kind, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
         """Test valuemap with value 1"""
@@ -470,6 +480,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_tovalues_with_cimtype(self, element_kind, server_arg,
                                    integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -483,6 +494,7 @@ class Test_ValueMapping(object):
         cimtype = type_from_name(integer_type)
         assert vm.tovalues(cimtype(1)) == 'one'
 
+    @log_entry_exit
     def test_tobinary_with_unicode(self, element_kind, server_arg,
                                    integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -493,8 +505,9 @@ class Test_ValueMapping(object):
         vm = self.setup_for_element(element_kind, server_arg, integer_type,
                                     is_array, valuemap, values)
 
-        assert vm.tobinary(u'one') == 1
+        assert vm.tobinary('one') == 1
 
+    @log_entry_exit
     def test_singles(self, element_kind, server_arg, integer_type,
                      is_array):
         # pylint: disable=redefined-outer-name
@@ -524,6 +537,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_singles_ranges(self, element_kind, server_arg, integer_type,
                             is_array):
         # pylint: disable=redefined-outer-name
@@ -561,6 +575,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_unclaimed(self, element_kind, server_arg, integer_type,
                        is_array):
         # pylint: disable=redefined-outer-name
@@ -584,6 +599,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_singles_ranges_unclaimed(self, element_kind, server_arg,
                                       integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -623,6 +639,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_singles_ranges_unclaimed2(self, element_kind, server_arg,
                                        integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -661,6 +678,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_min_max_single(self, element_kind, server_arg, integer_type,
                             is_array):
         # pylint: disable=redefined-outer-name
@@ -677,7 +695,7 @@ class Test_ValueMapping(object):
 
         values = []
         for v in valuemap:
-            values.append('val %s' % v)
+            values.append(f'val {v}')
 
         vm = self.setup_for_element(element_kind, server_arg, integer_type,
                                     is_array, valuemap, values)
@@ -700,6 +718,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_min_max_closed_ranges(self, element_kind, server_arg,
                                    integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -709,14 +728,14 @@ class Test_ValueMapping(object):
         maxvalue = type_from_name(integer_type).maxvalue
 
         valuemap = []
-        valuemap.append('%s..%s' % (minvalue, minvalue + 2))
-        valuemap.append('%s..%s' % (maxvalue - 2, maxvalue))
+        valuemap.append(f'{minvalue}..{minvalue + 2}')
+        valuemap.append(f'{maxvalue - 2}..{maxvalue}')
 
         exp_valuemap = [(minvalue, minvalue + 2), (maxvalue - 2, maxvalue)]
 
         values = []
         for v in valuemap:
-            values.append('val %s' % v)
+            values.append(f'val {v}')
 
         vm = self.setup_for_element(element_kind, server_arg, integer_type,
                                     is_array, valuemap, values)
@@ -743,6 +762,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_min_max_open_range1(self, element_kind, server_arg, integer_type,
                                  is_array):
         # pylint: disable=redefined-outer-name
@@ -752,17 +772,17 @@ class Test_ValueMapping(object):
         maxvalue = type_from_name(integer_type).maxvalue
 
         valuemap = []
-        valuemap.append('%s' % minvalue)
-        valuemap.append('..%s' % (minvalue + 2))
-        valuemap.append('%s..' % (maxvalue - 2))
-        valuemap.append('%s' % maxvalue)
+        valuemap.append(f'{minvalue}')
+        valuemap.append(f'..{minvalue + 2}')
+        valuemap.append(f'{maxvalue - 2}..')
+        valuemap.append(f'{maxvalue}')
 
         exp_valuemap = [minvalue, (minvalue + 1, minvalue + 2),
                         (maxvalue - 2, maxvalue - 1), maxvalue]
 
         values = []
         for v in valuemap:
-            values.append('val %s' % v)
+            values.append(f'val {v}')
 
         vm = self.setup_for_element(element_kind, server_arg, integer_type,
                                     is_array, valuemap, values)
@@ -791,6 +811,7 @@ class Test_ValueMapping(object):
             items.append(item)
         assert items == exp_items
 
+    @log_entry_exit
     def test_min_max_open_range2(self, element_kind, server_arg, integer_type,
                                  is_array):
         # pylint: disable=redefined-outer-name
@@ -800,15 +821,15 @@ class Test_ValueMapping(object):
         maxvalue = type_from_name(integer_type).maxvalue
 
         valuemap = []
-        valuemap.append('..%s' % (minvalue + 2))
-        valuemap.append('%s..' % (maxvalue - 2))
+        valuemap.append(f'..{minvalue + 2}')
+        valuemap.append(f'{maxvalue - 2}..')
 
         exp_valuemap = [(minvalue, minvalue + 2),
                         (maxvalue - 2, maxvalue)]
 
         values = []
         for v in valuemap:
-            values.append('val %s' % v)
+            values.append(f'val {v}')
 
         vm = self.setup_for_element(element_kind, server_arg, integer_type,
                                     is_array, valuemap, values)
@@ -902,6 +923,7 @@ class Test_ValueMapping(object):
         "exp_valuemap_list, exp_exc_type, exp_exc_msg_pattern, condition",
         testcases_integer_representations
     )
+    @log_entry_exit
     def test_integer_representations(
             self, desc, integer_type, is_array, values_str_list,
             valuemap_str_list, exp_valuemap_list, exp_exc_type,
@@ -939,6 +961,7 @@ class Test_ValueMapping(object):
             (1, 2),
         ]
     )
+    @log_entry_exit
     def test_tovalues_multiple_values(
             self, element_value, element_kind, server_arg, integer_type,
             is_array):
@@ -952,6 +975,7 @@ class Test_ValueMapping(object):
         result = vm.tovalues(element_value)
         assert result == ['one', 'two']
 
+    @log_entry_exit
     def test_tovalues_none(
             self, element_kind, server_arg, integer_type, is_array):
         # pylint: disable=redefined-outer-name
@@ -1025,6 +1049,7 @@ class Test_ValueMapping(object):
             ),
         ]
     )
+    @log_entry_exit
     def test_tovalues_different_sizes(
             self, valuemap, values, values_default, exp_exc, exp_values,
             element_kind, server_arg, integer_type, is_array):
