@@ -4,11 +4,10 @@
 Test _warnings module.
 """
 
-from __future__ import absolute_import, print_function
-
-import six
 import pytest
 
+from ..utils.pytest_extensions import log_entry_exit
+
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 # pylint: disable=redefined-builtin
 from ...utils import import_installed
@@ -28,7 +27,7 @@ from pywbem import Warning, ToleratedServerIssueWarning, \
 TEST_CONN_ID = 'fake-conn-id'
 
 # The expected connection information in exception messages
-TEST_CONN_STR = 'Connection id: %s' % TEST_CONN_ID
+TEST_CONN_STR = f'Connection id: {TEST_CONN_ID}'
 TEST_CONN_STR_NONE = 'Connection id: None'
 
 
@@ -38,26 +37,19 @@ def _assert_subscription(exc):
     """
 
     # Access by subscription is only supported in Python 2:
-    if six.PY2:
-        assert exc[:] == exc.args
-        for i, _ in enumerate(exc.args):
-            assert exc[i] == exc.args[i]
-            assert exc[i:] == exc.args[i:]
-            assert exc[0:i] == exc.args[0:i]
+    try:
+        _ = exc[:]
+    except TypeError:
+        pass
     else:
+        assert False, "Access by slice did not fail in Python 3"
+    for i, _ in enumerate(exc.args):
         try:
-            _ = exc[:]
+            _ = exc[i]  # noqa: F841
         except TypeError:
             pass
         else:
-            assert False, "Access by slice did not fail in Python 3"
-        for i, _ in enumerate(exc.args):
-            try:
-                _ = exc[i]  # noqa: F841
-            except TypeError:
-                pass
-            else:
-                assert False, "Access by index did not fail in Python 3"
+            assert False, "Access by index did not fail in Python 3"
 
 
 def _assert_connection(exc, conn_id_kwarg, exp_conn_str):
@@ -122,6 +114,7 @@ def conn_info(request):
     return request.param
 
 
+@log_entry_exit
 def test_simple(simple_class, simple_args, conn_info):
     # pylint: disable=redefined-outer-name
     """
