@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 #
 # (C) Copyright 2018 InovaDevelopment.com
 #
@@ -25,14 +24,13 @@ they were added later than original tests. They provide a test of the logic
 of processing complex associations including ternary associations (more than
 2 reference properties and subclasses of the association and result classes)
 """
-from __future__ import absolute_import, print_function
 
 import os
-import io
 
 import pytest
 
 from ...utils import skip_if_moftab_regenerated
+from ..utils.pytest_extensions import log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -226,14 +224,14 @@ def save_data(conn, mof, request, response, exp_response):
             conn.display_repository(dest=COMPLEX_MODEL_OUT_MOF)
 
         if not os.path.exists(COMPLEX_MODEL_MOF):
-            with io.open('complex_association_model.mof', 'w',
-                         encoding='utf-8') as f:
+            with open('complex_association_model.mof', 'w',
+                      encoding='utf-8') as f:
                 print(mof, file=f)
 
-        with io.open(PYWBEMCLI_CMDS, 'a', encoding='utf-8') as f:
-            print('%s ' % request, file=f)
-            print("Resp : %s" % response, file=f)
-            print("ExpResp : %s" % exp_response, file=f)
+        with open(PYWBEMCLI_CMDS, 'a', encoding='utf-8') as f:
+            print(f"{request} ", file=f)
+            print(f"Resp : {response}", file=f)
+            print(f"ExpResp : {exp_response}", file=f)
 
 
 X1 = """
@@ -318,6 +316,7 @@ instance of TST_A3Sub as $A3Sub511 {
          OK],
     ]
 )
+@log_entry_exit
 def test_complexref_classnames(conn, ns, target, ro, rc, mof, exp_rslt,
                                complex_assoc_mof, cond):
     # pylint: disable=redefined-outer-name,invalid-name
@@ -352,18 +351,18 @@ def test_complexref_classnames(conn, ns, target, ro, rc, mof, exp_rslt,
     exp_clns = [CIMClassName(classname=n, namespace=exp_ns, host=conn.host)
                 for n in exp_rslt]
 
-    request = "pywbemcli class references {0} --role {1} --result_class {2}". \
-        format(target, ro, rc)
+    request = (f"pywbemcli class references {target} --role {ro} "
+               f"--result_class {rc}")
     response = [c.classname for c in exp_clns]
     exp_response = [c.classname for c in exp_clns]
     save_data(conn, complex_assoc_mof, request, response, exp_response)
 
     if VERBOSE:
-        print('\nACT %s\nEXP %s' % ([c.classname for c in rtn_clns],
-                                    [c.classname for c in exp_clns]))
+        print('\nACT {}\nEXP {}'.format([c.classname for c in rtn_clns],
+                                        [c.classname for c in exp_clns]))
 
-    assert set(cln.classname.lower() for cln in exp_clns) == \
-        set(cln.classname.lower() for cln in rtn_clns)
+    assert {cln.classname.lower() for cln in exp_clns} == \
+        {cln.classname.lower() for cln in rtn_clns}
 
 
 @pytest.mark.parametrize(
@@ -471,6 +470,7 @@ def test_complexref_classnames(conn, ns, target, ro, rc, mof, exp_rslt,
         ),
     ]
 )
+@log_entry_exit
 def test_complexref_instnames(conn, ns, target, ro, rc, mof, exp_rslt,
                               complex_assoc_mof, cond):
     # pylint: disable=redefined-outer-name,invalid-name
@@ -526,11 +526,11 @@ def test_complexref_instnames(conn, ns, target, ro, rc, mof, exp_rslt,
     rtn_instnames_str = [str(n) for n in rtn_instnames]
     exp_instnames_str = [str(n) for n in exp_instnames]
     if VERBOSE:
-        print('\nACT:\n%s\nEXP:\n%s' % ("\n".join(rtn_instnames_str),
-                                        "\n".join(exp_instnames_str)))
+        print('\nACT:\n{}\nEXP:\n{}'.format("\n".join(rtn_instnames_str),
+                                            "\n".join(exp_instnames_str)))
 
-    request = "pywbemcli class references {0} --role {1} --result_class {2}". \
-        format(target_inst, ro, rc)
+    request = (f"pywbemcli class references {target_inst} --role {ro} "
+               f"--result_class {rc}")
     save_data(conn, complex_assoc_mof, request, rtn_instnames_str,
               exp_instnames_str)
 
@@ -602,6 +602,7 @@ def test_complexref_instnames(conn, ns, target, ro, rc, mof, exp_rslt,
 
     ]
 )
+@log_entry_exit
 def test_complexassoc_classnames(conn, ns, target, ro, rr, ac,
                                  rc, mof, exp_rslt, complex_assoc_mof, cond):
     # pylint: disable=redefined-outer-name,invalid-name
@@ -641,16 +642,15 @@ def test_complexassoc_classnames(conn, ns, target, ro, rr, ac,
     exp_clns = [CIMClassName(classname=n, namespace=exp_ns, host=conn.host)
                 for n in exp_rslt]
     if VERBOSE:
-        print('\nACT %s\nEXP %s' % ([c.classname for c in rtn_clns],
-                                    [c.classname for c in exp_clns]))
+        print('\nACT {}\nEXP {}'.format([c.classname for c in rtn_clns],
+                                        [c.classname for c in exp_clns]))
 
-    request = "pywbemcli class associators {0} --role {1} --assoc-class {2} " \
-        "--result-role {3} --result-class {4}". \
-        format(target, ro, ac, rr, rc)
+    request = (f"pywbemcli class associators {target} --role {ro} "
+               f"--assoc-class {ac} --result-role {rr} --result-class {rc}")
     save_data(conn, complex_assoc_mof, request, rtn_clns, exp_clns)
 
-    assert set(cln.classname.lower() for cln in exp_clns) == \
-        set(cln.classname.lower() for cln in rtn_clns)
+    assert {cln.classname.lower() for cln in exp_clns} == \
+        {cln.classname.lower() for cln in rtn_clns}
 
 
 @pytest.mark.parametrize(
@@ -1135,6 +1135,7 @@ def test_complexassoc_classnames(conn, ns, target, ro, rr, ac,
         ],
     ]
 )
+@log_entry_exit
 def test_complexassoc_instnames(conn, ns, target, ro, rr, ac,
                                 rc, mof, exp_rslt, complex_assoc_mof, cond):
     # pylint: disable=redefined-outer-name,invalid-name
@@ -1192,12 +1193,11 @@ def test_complexassoc_instnames(conn, ns, target, ro, rr, ac,
     rtn_instnames_str = [str(n) for n in rtn_instnames]
     exp_instnames_str = [str(n) for n in exp_instnames]
     if VERBOSE:
-        print('\nACT:\n%s\nEXP:\n%s' % ("\n".join(rtn_instnames_str),
-                                        "\n".join(exp_instnames_str)))
+        print('\nACT:\n{}\nEXP:\n{}'.format("\n".join(rtn_instnames_str),
+                                            "\n".join(exp_instnames_str)))
 
-    request = "pywbemcli class associators {0} --role {1} --assoc-class {2} " \
-        "--result-role {3} --result-class {4}". \
-        format(target_inst, ro, ac, rr, rc)
+    request = (f"pywbemcli class associators {target_inst} --role {ro} "
+               f"--assoc-class {ac} --result-role {rr} --result-class {rc}")
     save_data(conn, complex_assoc_mof, request, rtn_instnames_str,
               exp_instnames_str)
 
