@@ -14,14 +14,13 @@
 """
 Test of pywbem_mock package.  This tests the implementation of pywbem_mock
 using a set of local mock qualifiers, classes, and instances.
-
 """
-from __future__ import absolute_import, print_function
 
 import pickle
+
 import pytest
 
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -180,6 +179,7 @@ TESTCASES_OBJSTORE = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_OBJSTORE)
 @simplified_test_function
+@log_entry_exit
 def test_objectstore(testcase, init_args, cls_kwargs, inst_kwargs, qual_kwargs):
     # pylint: disable=unused-argument
     """
@@ -335,6 +335,7 @@ def test_objectstore(testcase, init_args, cls_kwargs, inst_kwargs, qual_kwargs):
         ('root/def', [], None, None, ValueError()),
     ]
 )
+@log_entry_exit
 def test_add_namespace(default_ns, additional_ns, test_ns, exp_ns, exp_exc):
     # pylint: disable=no-self-use
     """
@@ -373,6 +374,7 @@ def test_add_namespace(default_ns, additional_ns, test_ns, exp_ns, exp_exc):
         ('root/def', [], None, None, ValueError()),
     ]
 )
+@log_entry_exit
 def test_remove_namespace(default_ns, additional_ns, test_ns, exp_ns, exp_exc):
     # pylint: disable=no-self-use
     """
@@ -439,6 +441,7 @@ TEST_OBJECTS2 = [
         ),
     ],
 )
+@log_entry_exit
 def test_repository_valid_methods(desc, args, condition, capsys):
     """
     This is a test of the various methods of the repository that return
@@ -524,8 +527,7 @@ def test_repository_valid_methods(desc, args, condition, capsys):
     for type_dict, obj_dict in input_items.items():
         xxx_repo = repos[type_dict]
         for name, obj in obj_dict.items():
-            assert xxx_repo.object_exists(name), '{} exists() fail {}' \
-                .format(desc, name)
+            assert xxx_repo.object_exists(name), f'{desc} exists() fail {name}'
 
             rtnd_obj = xxx_repo.get(name)
             assert rtnd_obj == obj
@@ -591,6 +593,7 @@ def test_repository_valid_methods(desc, args, condition, capsys):
         ),
     ],
 )
+@log_entry_exit
 def test_repository_method_errs(desc, args, condition, capsys):
     # pylint: disable=unused-argument
     """
@@ -712,6 +715,7 @@ TESTCASES_REPO_PICKLE = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_REPO_PICKLE)
 @simplified_test_function
+@log_entry_exit
 def test_InMemoryRepository_pickle(testcase, init_namespace, init_objects):
     """
     Test function for pickling and unpickling InMemoryRepository objects
@@ -856,6 +860,7 @@ TESTCASES_REPO_LOAD = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_REPO_LOAD)
 @simplified_test_function
+@log_entry_exit
 def test_InMemoryRepository_load(testcase,
                                  init_namespace1, init_objects1,
                                  init_namespace2, init_objects2):
