@@ -13,12 +13,11 @@
 Test of pywbem_mock.ProviderRegistry.
 """
 
-from __future__ import absolute_import, print_function
-
 import pickle
+
 import pytest
 
-from ..utils.pytest_extensions import simplified_test_function
+from ..utils.pytest_extensions import simplified_test_function, log_entry_exit
 
 # pylint: disable=wrong-import-position, wrong-import-order, invalid-name
 from ...utils import import_installed
@@ -122,7 +121,7 @@ class TstMethodProvider1(MethodProvider):
     provider_classnames = None  # Will be set before use
 
     def __init__(self, cimrepository):
-        super(TstMethodProvider1, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
     def InvokeMethod(self, methodname, localobject, params):
         """Dummy provider method"""
@@ -135,7 +134,7 @@ class TstMethodProvider2(MethodProvider):
     provider_classnames = None  # Will be set before use
 
     def __init__(self, cimrepository):
-        super(TstMethodProvider2, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
     def InvokeMethod(self, methodname, localobject, params):
         """Dummy provider method"""
@@ -148,7 +147,7 @@ class TstInstWrProvider1(InstanceWriteProvider):
     provider_classnames = None  # Will be set before use
 
     def __init__(self, cimrepository):
-        super(TstInstWrProvider1, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
     def CreateInstance(self, namespace, new_instance):
         """Dummy provider method"""
@@ -161,7 +160,7 @@ class TstInstWrProvider2(InstanceWriteProvider):
     provider_classnames = None  # Will be set before use
 
     def __init__(self, cimrepository):
-        super(TstInstWrProvider2, self).__init__(cimrepository)
+        super().__init__(cimrepository)
 
     def CreateInstance(self, namespace, new_instance):
         """Dummy provider method"""
@@ -241,6 +240,7 @@ TESTCASES_PROVREG_ITERITEMS = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_PROVREG_ITERITEMS)
 @simplified_test_function
+@log_entry_exit
 def test_ProviderRegistry_iteritems(testcase, providers):
     """
     Test function for ProviderRegistry.iteritems().
@@ -329,6 +329,7 @@ TESTCASES_PROVREG_LOAD = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_PROVREG_LOAD)
 @simplified_test_function
+@log_entry_exit
 def test_ProviderRegistry_load(testcase, providers1, providers2):
     """
     Test function for ProviderRegistry.load().
@@ -398,6 +399,7 @@ TESTCASES_PROVREG_PICKLE = [
     "desc, kwargs, exp_exc_types, exp_warn_types, condition",
     TESTCASES_PROVREG_PICKLE)
 @simplified_test_function
+@log_entry_exit
 def test_ProviderRegistry_pickle(testcase, providers):
     """
     Test function for pickling and unpickling ProviderRegistry objects.
