@@ -2,37 +2,18 @@
 Extensions for pytest module.
 """
 
-from __future__ import absolute_import
 
 import functools
 import warnings
 from collections import namedtuple
-try:
-    from inspect import Signature, Parameter
-except ImportError:  # py2
-    from funcsigs import Signature, Parameter
+from inspect import signature
+import logging
+
 import pytest
 
 __all__ = ['simplified_test_function', 'ignore_warnings', 'expect_warnings']
 
 
-# Pytest determines the signature of the test function by unpacking any
-# wrapped functions (this is the default of the signature() function it
-# uses. We correct this behavior by setting the __signature__ attribute of
-# the wrapper function to its correct signature. To do that, we cannot use
-# signature() because its follow_wrapped parameter was introduced only in
-# Python 3.5. Instead, we build the signature manually.
-TESTFUNC_SIGNATURE = Signature(
-    parameters=[
-        Parameter('desc', Parameter.POSITIONAL_OR_KEYWORD),
-        Parameter('kwargs', Parameter.POSITIONAL_OR_KEYWORD),
-        Parameter('exp_exc_types', Parameter.POSITIONAL_OR_KEYWORD),
-        Parameter('exp_warn_types', Parameter.POSITIONAL_OR_KEYWORD),
-        Parameter('condition', Parameter.POSITIONAL_OR_KEYWORD),
-    ]
-)
-
-
 def simplified_test_function(test_func):
     """
     A decorator for test functions that simplifies the test function by
@@ -52,7 +33,7 @@ def simplified_test_function(test_func):
 
     Parameters of the wrapper function returned by this decorator:
 
-    * desc (string): Short testcase description.
+    * desc (str): Short testcase description.
 
     * kwargs (dict): Keyword arguments for the test function.
 
@@ -151,7 +132,7 @@ def simplified_test_function(test_func):
 
                     ret = None  # Debugging hint
                     assert len(rec_warnings) >= 1, \
-                        "Expected warning(s) missing: {}".format(exp_warn_types)
+                        f"Expected warning(s) missing: {exp_warn_types}"
         else:
             with warnings.catch_warnings(record=True) as rec_warnings:
                 if exp_exc_types:
@@ -186,12 +167,76 @@ def simplified_test_function(test_func):
                         raise AssertionError(msg)
         return ret
 
-    # Needed because the decorator is signature-changin
-    wrapper_func.__signature__ = TESTFUNC_SIGNATURE
+    # Needed because the decorator is signature-changing
+    wrapper_func.__signature__ = signature(wrapper_func)
 
     return functools.update_wrapper(wrapper_func, test_func)
 
 
+def logger_name(test_mod_name):
+    """
+    Return the logger name to be used for the specified test module.
+
+    Parameters:
+        test_mod_name (str): Test module name, qualified with the module path.
+    """
+    return test_mod_name.rsplit('.', maxsplit=1)[-1]
+
+
+def get_logger(test_mod_name):
+    """
+    Get the Python logger for the test module.
+
+    Parameters:
+        test_mod_name (str): Test module name, optionally qualified with the
+          module path.
+
+    Returns:
+        logging.Logger: Python logger for the test module.
+    """
+    _logger_name = logger_name(test_mod_name)
+    _logger = logging.getLogger(_logger_name)
+    return _logger
+
+
+def log_entry_exit(func):
+    """
+    A decorator for test functions that logs entry and exit of the test
+    function.
+    """
+    @functools.wraps(func)
+    def wrapper(*args, **kwargs):
+        test_mod_name = func.__module__  # qualified with module path
+        test_func_name = func.__qualname__
+        _logger = get_logger(test_mod_name)
+
+        # Set the following to True when there is a need to see the test
+        # function arguments in the log:
+        with_args = False
+
+        if with_args:
+            args_str = f" with args: {args!r}; kwargs: {kwargs!r}"
+        else:
+            args_str = ""
+        _logger.debug("Entering test function %s%s", test_func_name, args_str)
+        try:
+            result = func(*args, **kwargs)
+            return result
+        finally:
+            _logger.debug("Leaving test function %s", test_func_name)
+
+    return wrapper
+
+
+@pytest.fixture
+def logger(request):
+    """
+    Pytest fixture that resolves to the Python logger for the test module.
+    """
+    test_mod_name = request.node.module.name  # qualified with module path
+    return get_logger(test_mod_name)
+
+
 class ignore_warnings(warnings.catch_warnings):
     # pylint: disable=invalid-name,too-few-public-methods
     """
@@ -210,7 +255,7 @@ class ignore_warnings(warnings.catch_warnings):
                 Must be a single class, a list/tuple of classes, or None.
                 The classes must be subclasses of Warning.
         """
-        super(ignore_warnings, self).__init__()
+        super().__init__()
         if categories is None:
             categories = []
         elif not isinstance(categories, (list, tuple)):
@@ -220,7 +265,7 @@ class ignore_warnings(warnings.catch_warnings):
         self.categories = categories
 
     def __enter__(self):
-        ret = super(ignore_warnings, self).__enter__()  # saves current filters
+        ret = super().__enter__()  # saves current filters
         for category in self.categories:
             warnings.simplefilter('ignore', category=category)
         return ret
