@@ -60,9 +60,8 @@ Note: Changes in DSP0203 2.4.0, compared to 2.3.1:
         IMETHODRESPONSE, because they were not needed.
 """
 
-from __future__ import print_function, absolute_import
 
-import os.path
+import os
 import re
 from subprocess import Popen, PIPE, STDOUT
 
@@ -102,9 +101,9 @@ def validate_cim_xml(cim_xml_str, root_elem_name=None):
 
     Parameters:
 
-      cim_xml_str (string): CIM-XML string to be validated.
+      cim_xml_str (str): CIM-XML string to be validated.
 
-      root_elem_name (string): Name of XML element that is expected as the root
+      root_elem_name (str): Name of XML element that is expected as the root
         element in the CIM-XML string to be validated.
         `None` means no checking for a particular root element is performed.
 
@@ -121,12 +120,13 @@ def validate_cim_xml(cim_xml_str, root_elem_name=None):
 
     # Make sure the validator checks the specified root element, if any
     if root_elem_name is not None:
-        cim_xml_str = u'<!DOCTYPE {0} SYSTEM "{1}">\n{2}'. \
-            format(root_elem_name, dtd_file_fw, cim_xml_str)
+        cim_xml_str = (f'<!DOCTYPE {root_elem_name} SYSTEM "{dtd_file_fw}">\n'
+                       f'{cim_xml_str}')
         xmllint_cmd = 'xmllint --valid --noout -'
     else:
-        xmllint_cmd = 'xmllint --dtdvalid {0} --noout -'.format(dtd_file_fw)
+        xmllint_cmd = f'xmllint --dtdvalid {dtd_file_fw} --noout -'
 
+    # pylint: disable=consider-using-with
     p = Popen(xmllint_cmd, stdout=PIPE, stderr=STDOUT, stdin=PIPE, shell=True)
 
     cim_xml_str = _ensure_bytes(cim_xml_str)
@@ -173,32 +173,31 @@ def validate_cim_xml_obj(obj, obj_xml_str, exp_xml_str):
       obj (CIM object): The CIM object that belongs to the CIM-XML string,
        just for reporting purposes.
 
-      obj_xml_str (string): The CIM-XML string to be validated.
+      obj_xml_str (str): The CIM-XML string to be validated.
 
-      exp_xml_str (string): The expected CIM-XML string.
+      exp_xml_str (str): The expected CIM-XML string.
     """
 
-    assert _xml_semantic_compare(obj_xml_str, exp_xml_str), \
-        "Unexpected XML string (comparing at XML level):\n" \
-        "Actual:   {0!r}\n" \
-        "Expected: {1!r}\n".format(obj_xml_str, exp_xml_str)
+    assert _xml_semantic_compare(obj_xml_str, exp_xml_str), (
+        "Unexpected XML string (comparing at XML level):\n"
+        f"Actual:   {obj_xml_str!r}\n"
+        f"Expected: {exp_xml_str!r}\n")
 
     m = re.match(r'^<([^ >]+)', exp_xml_str)
-    assert m is not None, \
-        "Testcase issue: Cannot determine root element from expected " \
-        "CIM-XML string:\n{0}".format(exp_xml_str)
+    assert m is not None, (
+        "Testcase issue: Cannot determine root element from expected "
+        f"CIM-XML string:\n{exp_xml_str}")
     root_elem_name = m.group(1)
 
     try:
         validate_cim_xml(obj_xml_str, root_elem_name)
     except CIMXMLValidationError as exc:
         raise AssertionError(
-            "DTD validation of CIM-XML for {0} object failed:\n"
-            "{1}\n"
-            "Required XML root element: {2}\n"
+            f"DTD validation of CIM-XML for {type(obj)} object failed:\n"
+            f"{exc}\n"
+            f"Required XML root element: {root_elem_name}\n"
             "CIM-XML string:\n"
-            "{3}".
-            format(type(obj), exc, root_elem_name, obj_xml_str))
+            f"{obj_xml_str}")
 
 
 def assert_xml_equal(act_xml_str, exp_xml_str):
@@ -217,12 +216,12 @@ def assert_xml_equal(act_xml_str, exp_xml_str):
 
     Parameters:
 
-      act_xml_str (string): The actual XML string.
+      act_xml_str (str): The actual XML string.
 
-      exp_xml_str (string): The expected XML string.
+      exp_xml_str (str): The expected XML string.
     """
 
-    assert _xml_semantic_compare(act_xml_str, exp_xml_str), \
-        "Unexpected XML element (XML attribute order does not matter):\n" \
-        "Actual:   {0!r}\n" \
-        "Expected: {1!r}\n".format(act_xml_str, exp_xml_str)
+    assert _xml_semantic_compare(act_xml_str, exp_xml_str), (
+        "Unexpected XML element (XML attribute order does not matter):\n"
+        f"Actual:   {act_xml_str!r}\n"
+        f"Expected: {exp_xml_str!r}\n")
